CometChatCallButtons class

CometChatCallButtons is a button widget with voice and video call icons.

This widget uses BLoC pattern for state management and supports both user (direct call) and group (meeting) receivers.

CometChatCallButtons(
  user: User(),
  group: Group(),
);
Inheritance

Constructors

CometChatCallButtons({Key? key, User? user, Group? group, CometChatCallButtonsStyle? callButtonsStyle, OnError? onError, bool? hideVideoCallButton, bool? hideVoiceCallButton, Widget? voiceCallIcon, Widget? videoCallIcon, CometChatOutgoingCallConfiguration? outgoingCallConfiguration, SessionSettingsBuilder callSettingsBuilder(User? user, Group? group, bool? isAudioOnly)?, CallButtonsBloc? callButtonsBloc})
const

Properties

callButtonsBloc CallButtonsBloc?
final
callButtonsStyle CometChatCallButtonsStyle?
final
callSettingsBuilder SessionSettingsBuilder Function(User? user, Group? group, bool? isAudioOnly)?
final
group Group?
final
hashCode int
The hash code for this object.
no setterinherited
hideVideoCallButton bool?
final
hideVoiceCallButton bool?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onError OnError?
final
outgoingCallConfiguration CometChatOutgoingCallConfiguration?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user User?
final
videoCallIcon Widget?
final
voiceCallIcon Widget?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CometChatCallButtons>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited