ccCallAccepted method
ccCallAccepted is used to inform the listeners that a call is accepted by the logged-in user.
Implementation
@override
void ccCallAccepted(Call call) {
activeCall = call;
}
ccCallAccepted is used to inform the listeners that a call is accepted by the logged-in user.
@override
void ccCallAccepted(Call call) {
activeCall = call;
}