ccCallEnded method
ccCallEnded is used to inform the listeners that a call is ended by either the logged-in user.
Implementation
@override
void ccCallEnded(Call call) {
_clearActiveCall(call);
}
ccCallEnded is used to inform the listeners that a call is ended by either the logged-in user.
@override
void ccCallEnded(Call call) {
_clearActiveCall(call);
}