ccCallRejected method
ccCallRejected is used to inform the listeners that a call is rejected by the logged-in user.
Implementation
@override
void ccCallRejected(Call call) {
_clearActiveCall(call);
}
ccCallRejected is used to inform the listeners that a call is rejected by the logged-in user.
@override
void ccCallRejected(Call call) {
_clearActiveCall(call);
}