ccOutgoingCall method
ccOutgoingCall is used to inform the listeners that an outgoing call is initiated by the logged-in user.
Implementation
@override
void ccOutgoingCall(Call call) {
activeCall = call;
}
ccOutgoingCall is used to inform the listeners that an outgoing call is initiated by the logged-in user.
@override
void ccOutgoingCall(Call call) {
activeCall = call;
}