call_ui/src/call_logs/widgets/widgets library

Barrel export file for call logs widgets.

This file exports all modular widget components extracted from the CometChatCallLogs widget for better maintainability and reusability.

Classes

CallLogsEmptyView
A widget that displays the empty state for the call logs list.
CallLogsErrorView
A widget that displays the error state for the call logs list.
CallLogsList
A widget that displays the list of call logs.
CallLogsListItem
A widget that displays a single call log item in the list.
CallLogsLoadingView
A widget that displays the loading state for the call logs list.