CallingConfiguration class

Constructors

CallingConfiguration({CometChatOutgoingCallConfiguration? outgoingCallConfiguration, CometChatIncomingCallConfiguration? incomingCallConfiguration, CallButtonsConfiguration? callButtonsConfiguration, SessionSettingsBuilder? groupSessionSettingsBuilder})

Properties

callButtonsConfiguration CallButtonsConfiguration?
callButtonsConfiguration is a object of CallButtonsConfiguration which sets the configuration for call buttons
final
groupSessionSettingsBuilder SessionSettingsBuilder?
groupSessionSettingsBuilder is used to configure the meet session settings
final
hashCode int
The hash code for this object.
no setterinherited
incomingCallConfiguration CometChatIncomingCallConfiguration?
incomingCallConfiguration is a object of CometChatIncomingCallConfiguration which sets the configuration for incoming call
final
outgoingCallConfiguration CometChatOutgoingCallConfiguration?
outgoingCallConfiguration is a object of OutgoingCallConfiguration which sets the configuration for outgoing call
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited