isActiveCall property
ValueNotifier tracking whether there is an active ongoing call.
Implementation
final ValueNotifier<bool> isActiveCall = ValueNotifier<bool>(false);
ValueNotifier tracking whether there is an active ongoing call.
final ValueNotifier<bool> isActiveCall = ValueNotifier<bool>(false);