isActiveOutgoingCall property
ValueNotifier tracking whether there is an active outgoing call.
Implementation
final ValueNotifier<bool> isActiveOutgoingCall = ValueNotifier<bool>(false);
ValueNotifier tracking whether there is an active outgoing call.
final ValueNotifier<bool> isActiveOutgoingCall = ValueNotifier<bool>(false);