setActiveCallValue method
Sets the active call state.
Call this when an ongoing call session starts or ends.
Implementation
void setActiveCallValue(bool value) {
isActiveCall.value = value;
}
Sets the active call state.
Call this when an ongoing call session starts or ends.
void setActiveCallValue(bool value) {
isActiveCall.value = value;
}