setActiveIncomingValue method
Sets the active incoming call state.
Call this when an incoming call is received or dismissed.
Implementation
void setActiveIncomingValue(bool value) {
isActiveIncomingCall.value = value;
}
Sets the active incoming call state.
Call this when an incoming call is received or dismissed.
void setActiveIncomingValue(bool value) {
isActiveIncomingCall.value = value;
}