setActiveOutgoingValue method
Sets the active outgoing call state.
Call this when an outgoing call is initiated or ends.
Implementation
void setActiveOutgoingValue(bool value) {
isActiveOutgoingCall.value = value;
}
Sets the active outgoing call state.
Call this when an outgoing call is initiated or ends.
void setActiveOutgoingValue(bool value) {
isActiveOutgoingCall.value = value;
}