chat_ui/src/conversations/cometchat_conversations library
Classes
- CometChatConversations
- CometChatConversations is a component that shows all conversations involving the logged in user with the help of CometChatListBase and CometChatListItem By default, for each conversation that will be listed, the name of the user or group the logged in user is having conversation with will be displayed in the title of every list item, the subtitle will contain the last message in that conversation along with its receipt status, the leading view will contain the avatars of the user and groups and status indicator will indicate if users are online and icons for indicating a private or password protected group, and the trailing view will contain the time of the last message in that conversation and the number of unread messages.