chat_ui/src/conversations/conversations_builder_protocol library

Classes

ConversationsBuilderProtocol
ConversationsBuilderProtocol is an interface that defines the structure for fetching the conversation. It provides a generic requestBuilder property and methods getRequest and getSearchRequest that needs to be overridden.
UIConversationsBuilder
UIConversationsBuilder is the default ConversationsBuilderProtocol used when a custom conversations builder protocol is not passed