chat_ui/src/conversations/widgets/widgets library

Barrel export file for conversations widgets.

This file exports all modular widget components extracted from the CometChatConversations widget for better maintainability and reusability.

Classes

CometChatConversationListItem
CometChatConversationListItem is a dedicated widget for displaying a single conversation list item.
CometChatConversationListItemStyle
Style configuration for CometChatConversationListItem component.
ConversationsEmptyView
A widget that displays the empty state for the conversations list.
ConversationsErrorView
A widget that displays the error state for the conversations list.
ConversationsList
A widget that displays the list of conversations with state handling and pagination.
ConversationsLoadingView
A widget that displays the loading state for the conversations list.
ConversationsSubtitleView
A widget that displays the subtitle area for a conversation list item.
ConversationsTrailingView
A widget that displays the trailing area for a conversation list item.