CometChatCreatePoll class

CometChatCreatePoll is a widget used to create a poll bubble

CometChatCreatePoll(
 user: "uid",
 group: "guid",
 title: "Create Poll",
 );
Inheritance

Constructors

CometChatCreatePoll({Key? key, String? title, String? user, String? group, BaseMessage? quotedMessage, Group? groupObject, User? userObject, int defaultAnswers = 2})
const

Properties

defaultAnswers int
defaultAnswers min no. of default answers and default options cannot be deleted
final
group String?
group group id
final
groupObject Group?
groupObject group object for context
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
quotedMessage BaseMessage?
quotedMessage message being replied to — its id is sent with the poll creation request
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
title title default is 'Create Poll'
final
user String?
user user id
final
userObject User?
userObject user object for context
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CometChatCreatePoll>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited