GroupMemberUnbanned class

Event triggered when a member is unbanned from a group This is an internal event dispatched by SDK listeners

Inheritance

Constructors

GroupMemberUnbanned({required Action action, required User unbannedUser, required User unbannedBy, required Group group})
const

Properties

action Action
final
group Group
final
hashCode int
The hash code for this object.
no setterinherited
props List<Object>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
unbannedBy User
final
unbannedUser User
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited