GroupsError class

Error state with error message and optional previous data

Preserves previous groups data to allow displaying cached content while showing an error message.

Inheritance

Constructors

GroupsError({required String message, List<Group>? previousGroups})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Error message describing what went wrong
final
previousGroups List<Group>?
Previously loaded groups, if any, for graceful degradation
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited