chat_ui/src/groups/data/data library

Data layer exports for groups module This barrel file provides a single import point for all data layer components

Classes

GroupsRemoteDataSource
Abstract interface for groups remote data source Handles all interactions with CometChat SDK for groups
GroupsRemoteDataSourceImpl
Implementation of GroupsRemoteDataSource using CometChat SDK
GroupsRepositoryImpl
Implementation of GroupsRepository Coordinates between remote data source and domain layer

Exceptions / Errors

GroupsRemoteDataSourceException
Exception thrown when remote data source operations fail