chat_ui/src/groups/domain/domain library

Domain layer exports for groups module This barrel file provides a single import point for all domain layer components

Classes

GetGroupsUseCase
Use case for getting groups with pagination and search support
GetLoggedInUserUseCase
Use case for getting the currently logged-in user
GroupsRepository
Repository interface for groups data operations Defines the contract for group data access
JoinGroupUseCase
Use case for joining a group
LeaveGroupUseCase
Use case for leaving a group
LoadMoreGroupsUseCase
Use case for loading more groups with pagination support