chat_ui/src/groups/groups_builder_protocol library

Classes

GroupsBuilderProtocol
GroupsBuilderProtocol is an interface that defines the structure for fetching the groups. It provides a generic requestBuilder property and methods getRequest and getSearchRequest that needs to be overridden.
UIGroupsBuilder
UIGroupsBuilder is the default GroupsBuilderProtocol used when a custom builder protocol is not passed