chat_ui/src/message_composer/cometchat_message_preview library

Classes

CometChatMessagePreview
CometChatMessagePreview is a component that provides a bubble consisting of text that can be appended to the message composer, message bubble or any other component as desired. The appearance is similar to a quote block of markdown files.
CometChatMessagePreviewStyle