ComposerUtils class
Utility helpers for the message composer.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getReplyIcon(
BaseMessage message, BuildContext context, Color? color) → Widget? -
Returns a small icon widget representing the media type of
message, or null for plain text messages.