chat_ui/src/message_header/cometchat_message_header library

Classes

CometChatMessageHeader
CometChatMessageHeader is a widget which shows user/group details using CometChatListItem if its being shown for an User then the name of the user will be in the title of CometChatListItem and their online/offline status will be in the subtitleView if its being shown for an Group then the name of the group will be in the title of CometChatListItem and their member count will be in the subtitleView