chat_ui/src/message_header/message_header library

Classes

CometChatMessageHeader
CometChatMessageHeader is a widget which shows user/group details using CometChatListItem if its being shown for an User then the name of the user will be in the title of CometChatListItem and their online/offline status will be in the subtitleView if its being shown for an Group then the name of the group will be in the title of CometChatListItem and their member count will be in the subtitleView
CometChatMessageHeaderStyle
CometChatMessageHeaderStyle is a data class that has styling-related properties to customize the appearance of CometChatMessageHeader
GetGroupUseCase
Use case for getting a group by GUID
GetMessageHeaderLoggedInUserUseCase
Use case for getting the logged-in user
GetUserUseCase
Use case for getting a user by UID
GroupOwnershipChanged
Group ownership changed event
InitializeLoggedInUser
Internal event for initializing logged-in user This is used internally by the BLoC and should not be dispatched externally
MessageHeaderBloc
BLoC for managing message header state
MessageHeaderEvent
Base class for all message header events Uses Equatable for proper event comparison in BLoC
MessageHeaderRepository
Repository interface for message header data operations Defines the contract for message header data access
MessageHeaderRepositoryImpl
Implementation of MessageHeaderRepository using CometChat SDK
MessageHeaderServiceLocator
Service Locator for Message Header module Provides dependency injection for message header clean architecture Follows singleton pattern for consistent dependency resolution
MessageHeaderState
State class for message header BLoC Uses Equatable for proper state comparison
RefreshGroup
Refresh group data from SDK
RefreshUser
Refresh user data from SDK
SetGroup
Set group for the message header
SetUser
Set user for the message header
TypingEnded
Typing ended event
TypingStarted
Typing started event
UpdateGroupDetails
Update group details
UpdateGroupMemberCount
Update group member count
UpdateUserStatus
Update user status (online/offline)
UserBlocked
User blocked event
UserUnblocked
User unblocked event

Enums

MessageHeaderStatus
Enum representing the status of the message header