chat_ui/src/message_information/data/data library

Data layer barrel export for Message Information module

Exports the data sources and repository implementations.

Classes

MessageInformationDataSource
Abstract interface for message information data source Handles interactions with CometChat SDK for message receipt operations
MessageInformationDataSourceImpl
Implementation of MessageInformationDataSource using CometChat SDK
MessageInformationRepositoryImpl
Implementation of MessageInformationRepository

Exceptions / Errors

MessageInformationDataSourceException
Exception thrown when message information data source operations fail