chat_ui/src/threaded_header/widgets/cometchat_threaded_header library

Classes

CometChatThreadedHeader
CometChatThreadedHeader is a widget that displays a parent message and its reply count in a threaded conversation view.