chat_ui/src/threaded_header/widgets/widgets library

Classes

CometChatThreadedHeader
CometChatThreadedHeader is a widget that displays a parent message and its reply count in a threaded conversation view.