onItemUpdated method

  1. @override
void onItemUpdated(
  1. User oldItem,
  2. User newItem,
  3. List<User> updatedList
)
override

Called when an item is updated in the list. Override this method to add custom logic after item update.

oldItem - The item before update newItem - The item after update updatedList - The list after the update

Implementation

@override
void onItemUpdated(User oldItem, User newItem, List<User> updatedList) {
  if (!isClosed) {
    add(_ListStateChanged(users: updatedList, isEmpty: false));
  }
}