UsersLoaded class

Loaded state with user data

Inheritance

Constructors

UsersLoaded({required List<User> users, bool hasMore = true, Set<String> selectedUsers = const {}, bool isLoadingMore = false, String? searchKeyword})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hasMore bool
final
isLoadingMore bool
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchKeyword String?
final
selectedUsers Set<String>
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
users List<User>
Users list
final

Methods

copyWith({List<User>? users, bool? hasMore, Set<String>? selectedUsers, bool? isLoadingMore, String? searchKeyword}) UsersLoaded
Create a copy of this state with updated fields
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited