CometChatUsers class

CometChatUsers is a component that displays a list of users using Clean Architecture with BLoC pattern.

Inheritance

Constructors

CometChatUsers({Key? key, CometChatUsersStyle usersStyle = const CometChatUsersStyle(), ScrollController? scrollController, String? searchPlaceholder, Widget? backButton, bool showBackButton = true, Widget? searchBoxIcon, bool hideSearch = false, SelectionMode? selectionMode, dynamic onSelection(List<User>?, BuildContext)?, String? title, WidgetBuilder? loadingStateView, WidgetBuilder? emptyStateView, WidgetBuilder? errorStateView, List<Widget> appBarOptions(BuildContext context)?, bool? usersStatusVisibility = true, ActivateSelection? activateSelection, OnError? onError, VoidCallback? onBack, dynamic onItemTap(BuildContext context, User)?, dynamic onItemLongPress(BuildContext context, User)?, Widget? submitIcon, bool? hideAppbar = false, double? height, double? width, bool? stickyHeaderVisibility = false, String? searchKeyword, OnLoad<User>? onLoad, OnEmpty? onEmpty, Widget? subtitleView(BuildContext, User)?, Widget listItemView(User)?, Widget? titleView(BuildContext context, User user)?, Widget? leadingView(BuildContext context, User user)?, Widget? trailingView(BuildContext context, User user)?, UsersBloc? usersBloc, UsersRequestBuilder? usersRequestBuilder})
const

Properties

activateSelection ActivateSelection?
final
appBarOptions List<Widget> Function(BuildContext context)?
final
backButton Widget?
final
emptyStateView WidgetBuilder?
final
errorStateView WidgetBuilder?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
hideAppbar bool?
final
hideSearch bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leadingView Widget? Function(BuildContext context, User user)?
final
listItemView Widget Function(User)?
final
loadingStateView WidgetBuilder?
final
onBack VoidCallback?
final
onEmpty OnEmpty?
final
onError OnError?
final
onItemLongPress → dynamic Function(BuildContext context, User)?
final
onItemTap → dynamic Function(BuildContext context, User)?
final
onLoad OnLoad<User>?
final
onSelection → dynamic Function(List<User>?, BuildContext)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollController ScrollController?
final
searchBoxIcon Widget?
final
searchKeyword String?
final
searchPlaceholder String?
final
selectionMode SelectionMode?
final
showBackButton bool
final
stickyHeaderVisibility bool?
final
submitIcon Widget?
final
subtitleView Widget? Function(BuildContext, User)?
final
title String?
final
titleView Widget? Function(BuildContext context, User user)?
final
trailingView Widget? Function(BuildContext context, User user)?
final
usersBloc UsersBloc?
final
usersRequestBuilder UsersRequestBuilder?
usersRequestBuilder custom request builder for filtering users
final
usersStatusVisibility bool?
final
usersStyle CometChatUsersStyle
final
width double?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CometChatUsers>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited