CometChatUsersStyle class

CometChatUsersStyle is a data class that has styling-related properties to customize the appearance of CometChatUsers

Inheritance

Constructors

CometChatUsersStyle({Color? backgroundColor, Border? border, BorderRadiusGeometry? borderRadius, Color? backIconColor, TextStyle? titleTextStyle, Color? titleTextColor, TextStyle? emptyStateTextStyle, Color? emptyStateTextColor, TextStyle? errorStateTextStyle, Color? errorStateTextColor, TextStyle? emptyStateSubTitleTextStyle, Color? emptyStateSubTitleTextColor, TextStyle? errorStateSubTitleTextStyle, Color? errorStateSubTitleTextColor, TextStyle? itemTitleTextStyle, Color? itemTitleTextColor, Color? separatorColor, double? separatorHeight, CometChatAvatarStyle? avatarStyle, CometChatStatusIndicatorStyle? statusIndicatorStyle, Color? searchBackgroundColor, BorderSide? searchBorder, BorderRadius? searchBorderRadius, Color? searchIconColor, Color? searchInputTextColor, TextStyle? searchInputTextStyle, Color? searchPlaceHolderTextColor, TextStyle? searchPlaceHolderTextStyle, Color? checkBoxBackgroundColor, BorderSide? checkBoxBorder, BorderRadiusGeometry? checkBoxBorderRadius, Color? checkBoxCheckedBackgroundColor, Color? listItemSelectedBackgroundColor, Color? checkboxSelectedIconColor, Color? submitIconColor, Color? retryButtonBackgroundColor, BorderSide? retryButtonBorder, BorderRadiusGeometry? retryButtonBorderRadius, Color? retryButtonTextColor, TextStyle? retryButtonTextStyle, BoxBorder? itemBorder, Color? stickyTitleColor, TextStyle? stickyTitleTextStyle})
const

Properties

avatarStyle CometChatAvatarStyle?
avatarStyle set style for avatar
final
backgroundColor Color?
backgroundColor provides background color for the widget
final
backIconColor Color?
backIconColor provides color for the back icon
final
border Border?
border provides border for the widget
final
borderRadius BorderRadiusGeometry?
borderRadius provides border radius for the widget
final
checkBoxBackgroundColor Color?
checkBoxBackgroundColor provides background color for selected item
final
checkBoxBorder BorderSide?
checkBoxBorder provides border for selected item
final
checkBoxBorderRadius BorderRadiusGeometry?
checkBoxBorderRadius provides border radius for selected item
final
checkBoxCheckedBackgroundColor Color?
checkBoxCheckedBackgroundColor provides check color for selected item
final
checkboxSelectedIconColor Color?
checkboxSelectedIconColor provides color for selected item
final
emptyStateSubTitleTextColor Color?
emptyStateSubTitleTextColor provides text color for empty state
final
emptyStateSubTitleTextStyle TextStyle?
emptyStateSubTitleTextStyle provides text style for empty state
final
emptyStateTextColor Color?
emptyStateTextColor provides text color for empty state
final
emptyStateTextStyle TextStyle?
emptyStateTextStyle provides text style for empty state
final
errorStateSubTitleTextColor Color?
errorStateSubTitleTextColor provides sub-title text color for error state
final
errorStateSubTitleTextStyle TextStyle?
errorStateTextStyle provides sub-title text style for error state
final
errorStateTextColor Color?
errorStateTextColor provides text color for error state
final
errorStateTextStyle TextStyle?
errorStateTextStyle provides text style for error state
final
hashCode int
The hash code for this object.
no setterinherited
itemBorder BoxBorder?
itemBorder provides border for the item
final
itemTitleTextColor Color?
itemTitleTextColor provides text color for item tile title
final
itemTitleTextStyle TextStyle?
itemTitleTextStyle provides text style for item tile title
final
listItemSelectedBackgroundColor Color?
listItemSelectedBackgroundColor provides background color for selected item
final
retryButtonBackgroundColor Color?
retryButtonBackgroundColor provides background color for retry button
final
retryButtonBorder BorderSide?
retryButtonBorder provides border for retry button
final
retryButtonBorderRadius BorderRadiusGeometry?
retryButtonBorderRadius provides border radius for retry button
final
retryButtonTextColor Color?
retryButtonTextColor provides text color for retry button
final
retryButtonTextStyle TextStyle?
retryButtonTextStyle provides text style for retry button
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchBackgroundColor Color?
searchBackgroundColor provides background color for search box
final
searchBorder BorderSide?
searchBorder provides border for search box
final
searchBorderRadius BorderRadius?
searchBorderRadius provides padding for search box content
final
searchIconColor Color?
searchIconColor provides color for search icon
final
searchInputTextColor Color?
searchInputTextColor provides input text color for search box
final
searchInputTextStyle TextStyle?
searchInputTextStyle provides input text style for search box
final
searchPlaceHolderTextColor Color?
searchPlaceHolderTextColor provides placeholder text color for search box
final
searchPlaceHolderTextStyle TextStyle?
searchPlaceHolderTextStyle provides placeholder text style for search box
final
separatorColor Color?
separatorColor provides color for the separator
final
separatorHeight double?
separatorHeight provides height for the separator
final
statusIndicatorStyle CometChatStatusIndicatorStyle?
statusIndicatorStyle set style for status indicator
final
stickyTitleColor Color?
stickyTitleColor provides text color for alphabet
final
stickyTitleTextStyle TextStyle?
stickyTitleTextStyle provides text style for alphabet
final
submitIconColor Color?
submitIconColor provides color for submit icon
final
titleTextColor Color?
titleTextColor provides text color for the title
final
titleTextStyle TextStyle?
title provides title for the widget
final
type Object
The extension's type.
no setterinherited

Methods

copyWith({Color? backgroundColor, Border? border, BorderRadiusGeometry? borderRadius, Color? backIconColor, TextStyle? titleTextStyle, Color? titleTextColor, TextStyle? emptyStateTextStyle, Color? emptyStateTextColor, TextStyle? errorStateTextStyle, Color? errorStateTextColor, TextStyle? emptyStateSubtitleTextStyle, Color? emptyStateSubtitleTextColor, TextStyle? errorStateSubTitleTextStyle, Color? errorStateSubTitleTextColor, TextStyle? itemTitleTextStyle, Color? itemTitleTextColor, double? separatorHeight, Color? separatorColor, CometChatAvatarStyle? avatarStyle, CometChatStatusIndicatorStyle? statusIndicatorStyle, Color? searchBackgroundColor, BorderSide? searchBorder, BorderRadius? searchBorderRadius, Color? searchIconColor, Color? searchInputTextColor, TextStyle? searchInputTextStyle, Color? searchPlaceHolderTextColor, TextStyle? searchPlaceHolderTextStyle, BorderSide? checkBoxBorder, Color? checkBoxBackgroundColor, Color? checkBoxCheckedBackgroundColor, BorderRadiusGeometry? checkBoxBorderRadius, Color? listItemSelectedBackgroundColor, Color? checkboxSelectedIconColor, Color? submitIconColor, Color? retryButtonBackgroundColor, Color? retryButtonTextColor, TextStyle? retryButtonTextStyle, BorderSide? retryButtonBorder, BorderRadiusGeometry? retryButtonBorderRadius, BoxBorder? itemBorder, Color? stickyTitleColor, TextStyle? stickyTitleTextStyle}) CometChatUsersStyle
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<CometChatUsersStyle>? other, double t) CometChatUsersStyle
Linearly interpolate with another ThemeExtension object.
override
merge(CometChatUsersStyle? style) CometChatUsersStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) CometChatUsersStyle