chat_ui/src/users/data/data library

Classes

UsersLocalDataSource
Abstract interface for users local data source Handles local caching of users
UsersLocalDataSourceImpl
In-memory implementation of UsersLocalDataSource
UsersRemoteDataSource
Abstract interface for users remote data source Handles all interactions with CometChat SDK
UsersRemoteDataSourceImpl
Implementation of UsersRemoteDataSource using CometChat SDK
UsersRepositoryImpl
Implementation of UsersRepository Coordinates between remote and local data sources

Exceptions / Errors

UsersLocalDataSourceException
Exception thrown when local data source operations fail
UsersRemoteDataSourceException
Exception thrown when remote data source operations fail