chat_ui/src/users/domain/domain library

Classes

BlockUserUseCase
Use case for blocking a user
GetLoggedInUserUseCase
Use case for getting the currently logged-in user
GetUsersUseCase
Use case for getting users with pagination and search support
GetUserUseCase
Use case for getting a specific user by UID
UnblockUserUseCase
Use case for unblocking a user
UsersRepository
Repository interface for users data operations Defines the contract for user data access