chat_ui/src/users/users_builder_protocol library
Classes
- UIUsersBuilder
- UIUsersBuilder is the default UsersBuilderProtocol used when a custom builder protocol is not passed
- UsersBuilderProtocol
- UsersBuilderProtocol is an interface that defines the structure for fetching the users. It provides a generic requestBuilder property and methods getRequest and getSearchRequest that needs to be overridden.