readByMeAt property
Timestamp when the message was read by the logged-in user.
Android: long readByMeAt (primitive, 0 = not set)
Implementation
DateTime? readByMeAt;
Timestamp when the message was read by the logged-in user.
Android: long readByMeAt (primitive, 0 = not set)
DateTime? readByMeAt;