CometChatCardAvatarElement class final

An avatar element showing an image or fallback initials in a circle.

Inheritance

Constructors

CometChatCardAvatarElement({required String id, String? imageUrl, String? fallbackInitials, double? size, double? borderRadius, dynamic backgroundColor, double? fontSize, String? fontWeight})
const
CometChatCardAvatarElement.fromJson(Map<String, dynamic> json)
factory

Properties

backgroundColor → dynamic
final
borderRadius double?
final
fallbackInitials String?
final
fontSize double?
final
fontWeight String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
finalinherited
imageUrl String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double?
final
type String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited