CometChatCardColorValue class

A theme-aware value with separate light and dark variants.

Used for colors (hex strings like "#FFFFFF") and also for theme-aware URLs on image/icon elements.

Constructors

CometChatCardColorValue({required String light, required String dark})
const
CometChatCardColorValue.fromJson(Map<String, dynamic> json)
factory

Properties

dark String
The value to use in dark theme mode.
final
hashCode int
The hash code for this object.
no setteroverride
light String
The value to use in light theme mode.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override