CometChatCardElement class sealed

Base sealed class for all 20 element types.

Uses Dart 3 sealed classes for exhaustive switch/case pattern matching.

Constructors

CometChatCardElement.fromJson(Map<String, dynamic> json)
Deserializes a JSON map into the appropriate element subclass based on the "type" discriminator field.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited