allowSenderInteraction property
Whether the sender can interact with their own message.
Android: boolean allowSenderInteraction - primitive, defaults to false
Implementation
bool allowSenderInteraction;
Whether the sender can interact with their own message.
Android: boolean allowSenderInteraction - primitive, defaults to false
bool allowSenderInteraction;