LogLayer enum

Layers of the SDK that can have logging enabled/disabled independently.

Android Reference: Logging categories in Android SDK Logger

Inheritance
Available extensions

Values

socket → const LogLayer

WebSocket transport layer.

http → const LogLayer

HTTP transport layer.

repository → const LogLayer

Domain repository layer.

api → const LogLayer

API endpoint layer.

auth → const LogLayer

Authentication layer.

bootstrap → const LogLayer

SDK bootstrap/initialization layer.

client → const LogLayer

SDK client facade layer.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LogLayer>
A constant List of the values in this enum, in order of their declaration.