shared_ui/cometchat_uikit_shared library
The cometchat_uikit_shared library.
This library provides shared utilities for the CometChat UIKit. It consolidates various resources, constants, events, utilities, and views required for CometChat to function.
Classes
- Action
- This class represents an action performed in the chat.
- ActionElementFields
- ActionElementUtils
- ActionEntity
- A base class for representing actions in a chat application.
- ActionItem
- ActionItem is the type of items displayed in CometChatAttachmentOptionSheet
- ActionMessageTypeConstants
- ActionTypeConstants
- AdditionalConfigurations
- AdditionalConfigurations is a class that can be used to add additional configurations to the UI Kit
- AgenticKeys
- AIAssistantBaseEvent
- AIAssistantContentReceivedEvent
- AIAssistantMessage
- Represents an AI Assistant message within the chat.
- AIAssistantMessageEndedEvent
- Represents an event when an AI Assistant message has ended.
- AIAssistantRunFinishedEvent
- Represents an event when an AI Assistant run has finished.
- AIAssistantRunStartedEvent
- Represents an event when an AI Assistant run has started.
- AIAssistantToolArgumentEvent
- Represents an AI Assistant tool argument event.
- AIAssistantToolEndedEvent
- Represents an AI Assistant tool ended event.
- AIAssistantToolResultEvent
- Represents an AI Assistant tool result event.
- AIAssistantToolStartedEvent
- Represents an AI Assistant tool started event.
- AIConstants
- Constants used by AI assistant features.
- AIFeatureConstants
- String constants for AI feature names.
- AIOptionsStyle
- Style for individual AI option items in the option sheet.
- AIToolArgumentMessage
- Represents a tool argument message in AI Assistant.
- AIToolCall
- Represents a tool call used in AI Assistant messages.
- AIToolCallFunction
- Represents a function call associated with an AI tool call.
- AIToolResultMessage
- Represents a tool result message in AI Assistant.
- AIUtils
- APIAction
- Represents an action that makes an API request in a chat application.
- APIRequestTypeConstants
- AppEntity
- Represents an entity within the application.
- AppSettings
- Represents application settings.
- AppSettingsBuilder
-
Builder class for
AppSettings. - AssetConstants
- AssetConstants is a utility class that stores String constants of asset image paths
- Attachment
- Represents a file attachment.
- AttributedText
- AttributedText is a class which is used to style the text
- AudioBubbleConstants
- AudioBubbleEvents
- AudioBubbleFactory
- Factory for creating audio message bubbles.
- AudioBubbleStream
- AudioBubbleStream a singleton class to handle the audio bubble events stream
- AudioServiceLocator
- Service Locator for Audio Bubble use cases Provides convenient access to audio-related use cases Wires to SharedUiServiceLocator for dependency resolution
- AudioStateEntity
- AudioStateManager
- Global state manager for audio bubbles to preserve playback state across widget rebuilds
- AudioStateRepository
- Abstract repository for Audio State management
- AudioStateUpdateEntity
- Event emitted when audio state changes
- BannedGroupMembersRequest
- A request object for fetching banned group members.
- BannedGroupMembersRequestBuilder
-
Builder class for
BannedGroupMembersRequest. -
BaseInputElement<
T> - BaseInteractiveElement
- BaseMessage
- Represents a basic chat message.
- BaseStyles
- BaseStyles is the base style class for most style classes provided by CometChatUIKit
- BlockedUsersRequest
- A request object for fetching blocked users.
- BlockedUsersRequestBuilder
-
Builder class for
BlockedUsersRequest. -
BubbleFactory<
T extends BaseMessage> - Abstract factory for creating message bubble content widgets.
- BubbleUtils
-
BuilderProtocol<
T1, T2> -
BuilderProtocol is the Marker class to define protocols
Used to generate different request builders
T1 is the type of Request builder to be passed and T2 should be the respective request type
eg for user list
T1will be UsersRequestBuilder andT2will be UsersRequest - ButtonElement
- Represents a button model class , used to draw button element .
- ButtonElementStyle
- Call
- Represents a call event within the chat.
- CallStatusConstants
- CallStatusConstants is a utility class that stores String constants of various stages of Call
- CallTypeConstants
- CardBubbleStyle
- CardBubbleStyle is a model class for card widget. It contains the styles for the card widget.
- CardMessage
- Represents a message with a card view that contains interactive elements.
- CardMessageKeys
- CardStyle
- CardStyle is a model class for card widget. It contains the styles for the card widget.
- CCExtension
- Represents a CometChat extension.
- ChatSDKEventInitializer
- CheckBoxElement
- Represents a checkbox model class , used to draw checkbox .
- CheckBoxElementStyle
-
CircularIntervalList<
T> - CometChat
- Flutter wrapper for using CometChat SDK.
- CometChatActionBubble
- creates a widget that gives group action bubble
- CometChatActionBubbleStyle
- CometChatActionBubbleStyle is a data class that has styling-related properties to customize the appearance of group action message bubble
- CometChatAIAssistantBubble
- Renders a completed AI assistant message with full markdown support.
- CometChatAIAssistantBubbleStyle
- Styling properties for CometChatAIAssistantBubble.
- CometChatAiAssistantCodeBlock
- CometChatAIAssistantEvents
- Event emitting class for AI Assistant features.
- CometChatAiAssistantTableBuilder
- CometChatAIConversationStarterStyle
- Styling properties for CometChatAIConversationStarterView.
- CometChatAIConversationStarterView
- Displays AI-generated conversation starter suggestions as tappable chips.
- CometChatAIConversationSummaryStyle
- Styling properties for CometChatAIConversationSummaryView.
- CometChatAIConversationSummaryView
- Displays an AI-generated conversation summary.
- CometChatAiOptionSheetStyle
- Styling properties for the AI option sheet bottom modal.
- CometChatAISmartRepliesStyle
- Styling properties for CometChatAISmartRepliesView.
- CometChatAISmartRepliesView
- Displays AI-generated smart reply suggestions as tappable chips.
- CometChatAnimatedMessageList
- An animated list widget for displaying chat messages
- CometChatAttachmentOptionSheet
- CometChatAttachmentOptionSheet is a widget that displays a list of options to choose from in a bottom sheet.
- CometChatAttachmentOptionSheetStyle
- CometChatAttachmentOptionSheetStyle is a class that allows you to customize the attachment action sheet. It takes backgroundColor, border, borderRadius, titleTextStyle, titleColor, iconColor as a parameter.
- CometChatAudioBubble
- CometChatAudioBubble creates a widget that gives audio bubble
- CometChatAudioBubbleStyle
- CometChatAudioBubbleStyle is a data class that has styling-related properties to customize the appearance of CometChatAudioBubble
- CometChatAudioBubbleV2
- Rewritten CometChatAudioBubble with lazy loading and gesture-controlled waveform
- CometChatAvatar
- CometChatAvatar is a widget that gives a container for avatar images
- CometChatAvatarStyle
- CometChatAvatarStyle is a data class that has styling-related properties to customize the appearance of CometChatAvatar
- CometChatBadge
- CometChatBadge is a widget to display a small amount of information about its a component like a count or status
- CometChatBadgeStyle
- CometChatBadgeStyle is a data class that has styling-related properties to customize the appearance of CometChatBadge
- CometChatBaseOptions
- CometChatBaseOptions is a model class which contains a set of properties that is be used by CometChatDetailsOption, CometChatGroupMemberOption thus forming a common base class for both
- CometChatBlockedUsersDirection
- CometChatCallBubbleStyle
- CometChatCallBubbleStyle is a data class that has styling-related properties to customize the appearance of CometChatCallBubble
- CometChatCallButtonsStyle
- CometChatCallButtonsStyle is the data class that contains style configuration for CometChatCallButtons
- CometChatCallEvents
- class for handling call events.
- CometChatCallStatus
- CometChatCallType
- CometChatCard
- CometChatCard is a prebuilt widget which is used to display a card with title, subtitle, avatar and bottom view.
- CometChatCardBubble
- CometChatCardBubble creates the card view for InteractiveMessage with type MessageTypeConstants.card by default
- CometChatCollaborativeBubbleStyle
- CometChatCollaborativeBubbleStyle is a data class that has styling-related properties to customize the appearance of CometChatCollaborativeBubble
- CometChatColorHelper
- The CometChatColorHelper class provides methods to blend two colors together and generate a color palette based on the base color and blend color provided.
- CometChatColorPalette
- The CometChatColorPalette class provides a color palette for the CometChat UI Kit.
- CometChatConfirmDialog
-
CometChatConfirmDialogis a class that allows you to show a customizable confirmation dialog with a title, message, icon, and two buttons. - CometChatConfirmDialogStyle
-
CometChatConfirmDialogStyle is a data class that has styling-related properties
to customize the appearance of
showCometChatConfirmDialog - CometChatConversationEvents
-
Event emitting class for
CometchatConversation - CometChatConversationType
- CometChatDate
- CometChatDate is a widget that provides a customizable container to display date and time
- CometChatDateStyle
- CometChatDateStyle is a data class that has styling-related properties to customize the appearance of CometChatDate
- CometChatDecoratedContainer
- CometChatDeletedBubble
- CometChatDeletedBubble is a widget that provides a placeholder for messages thave been deleted
- CometChatDeletedBubbleStyle
- CometChatDeletedBubbleStyle is a data class that has styling-related properties to customize the appearance of CometChatDeletedBubble
- CometChatDetailsControllerProtocol
- CometChatDetailsOption
- CometChatDetailsOption is a model class which contains information about options available for every CometChatDetailsTemplate
- CometChatDetailsTemplate
-
CometChatDetailsTemplate is the section of options displayed in
CometChatDetails - CometChatEmailFormatter
- CometChatEmailFormatter is a class which is used to style the email text
- CometChatExceptionStyle
- CometChatExceptionStyle is a data class that has styling-related properties for exception view
- CometChatFileBubble
- CometChatFileBubble creates a widget that gives file bubble
- CometChatFileBubbleStyle
- CometChatFileBubbleStyle is a data class that has styling-related properties to customize the appearance of CometChatFileBubble
- CometChatGroupEvents
- CometChatGroupMemberOption
- CometChatGroupMemberOption is a model class which contains information about options available to execute for every GroupMember
- CometChatGroupMembersControllerProtocol
- CometChatGroupType
- CometChatHelper
- CometchatHighlightBuilder
- CometChatImageBubble
- CometChatImageBubble creates a widget that gives image bubble
- CometChatImageBubbleStyle
- CometChatImageBubbleStyle is a data class that has styling-related properties to customize the appearance of CometChatImageBubble
- CometChatIncomingMessageBubbleStyle
- CometChatIncomingMessageBubbleStyle is a data class that has styling-related properties to customize the appearance of the incoming message bubble
- CometchatLinkBuilder
- CometChatLinkPreviewBubbleStyle
- CometChatLinkPreviewBubbleStyle is a data class that has styling-related properties to customize the appearance of CometChatLinkPreviewBubble
- CometChatListBase
- CometChatListBase is a top level container widget used internally by components like CometChatUsers, CometChatGroups, CometChatConversations, CometChatGroupMembers
-
CometChatListController<
T1, T2> - Common Controller Class which holds the logic to fetch data from different request builders
- CometChatListItem
-
CometChatListItem is a top level container widget
used internally for displaying each item in components like
CometChatUsers,CometChatGroups,CometChatConversations,CometChatGroupMembers - CometChatMarquee
- CometChatMediaRecorder
- CometChatMediaRecorder is a class that allows users to record audio messages. It has a start button to start recording, a stop button to stop recording, a play button to play the recorded message, a pause button to pause the recorded message, a submit button to submit the recorded message and a close button to close the media recorder.
- CometChatMediaRecorderStyle
- CometChatMediaRecorderStyle is a model class for customizing the styles of CometChatMediaRecorder widget.
- CometChatMemberScope
- CometChatMentionsFormatter
-
CometChatMentionsFormatter is a class which is used to format the mentions
It extends the CometChatTextFormatter
It has properties like composerId, onError, suggestionListEventSink, previousTextEventSink, message, mentionedUsersMap, mentionCount, mentionStartIndex, mentionEndIndex, lastCursorPos
It has methods like handlePreMessageSend, initializeFetchRequest, fetchItems, onMessageEdit, resetMentionsTracker, cursorInMentionTracker, onChange, onScrollToBottom
It has a constructor which takes trackingCharacter, pattern,
disableSuggestions, showLoadingIndicator, onSearch, group, composerId, onError, suggestionListEventSink, previousTextEventSink, theme, message, messageBubbleTextStyle, groupMembersRequestBuilder, usersRequestBuilder, messageInputTextStyle as a parameter It has a method onMentionTap which is used to handle the mention tap - CometChatMentionsStyle
- CometChatMentionsStyle is a data class that has styling-related properties to customize the appearance of mentions in the message
- CometChatMessageBubble
-
CometChatMessageBubble is a widget that provides the skeleton structure for any message bubble
constructed from a CometChatMessageTemplate which doesnt have a
bubbleViewit binds together the leadingView, headerView, contentView, footerView, bottomView, threadView declared in the CometChatMessageTemplate to collectively form a message bubble - CometChatMessageBubbleStyle
- CometChatMessageBubbleStyle is a data class that has styling-related properties to customize the appearance of CometChatMessageBubble
- CometChatMessageBubbleStyleData
- CometChatMessageBubbleStyleData is a model class which contains the style properties for the message bubble.
- CometChatMessageCategory
- CometChatMessageComposerAction
-
CometChatMessageComposerAction is the type of menu items allowed to be displayed
CometChatMessageComposer - CometChatMessageEvents
-
Event emitting class for
CometChatMessages - CometChatMessageInput
- CometChatMessageInput is a component that provides a skeleton layout for contents of CometChatMessageComposer like TextField, auxiliary options, primary button view and attachment options.
- CometChatMessageInputStyle
- CometChatMessageInputStyle is a data class that has styling-related properties to customize the appearance of CometChatMessageInput
- CometChatMessageListControllerProtocol
- CometChatMessageOption
- Model class for message options
- CometChatMessageOptionSheetStyle
- CometChatMessageOptionSheetStyle is a class that holds the styling of the message options sheet. This class is used to set the styling for the message options sheet in the CometChatMessageActionSheet. Use this class to set the styling of the message options sheet. This class provides the following options to customize the message options sheet:
- CometChatMessageReceiptStyle
- CometChatMessageReceiptStyle is a data class that has styling-related properties to customize the appearance of CometChatReceipt
- CometChatMessageTemplate
- CometChatMessageTemplate class for setting message types and rendering appropriate views in the message list
- CometChatMessageTranslationBubbleStyle
- CometChatMessageTranslationBubbleStyle is a data class that has styling-related properties to customize the appearance of MessageTranslationBubble
- CometChatMessageType
- CometChatModerationStyle
- CometChatModerationStyle is a data class that has styling-related properties for moderated view
- CometChatNewMessageIndicator
- A horizontal divider with centered "New Messages" text.
- CometChatNewMessageIndicatorStyle
- Style configuration for CometChatNewMessageIndicator.
- CometChatNotificationErrorCode
- CometChatNotificationErrorMessages
- CometChatNotifications
- Provides notification management functionality for CometChat.
- CometChatOption
- CometChatOption is a model class which is used to execute any action on a CometChatListItem
- CometChatOutgoingMessageBubbleStyle
- CometChatOutgoingMessageBubbleStyle is a data class that has styling-related properties to customize the appearance of the outgoing message bubble
- CometChatPhoneNumberFormatter
- CometChatPhoneNumberFormatter is a class which is used to style the phone number text
- CometChatPollsBubbleStyle
-
PollsBubbleStyleis a data class that has styling-related properties to customize the appearance of CometChatPollsBubble - CometChatQuickView
-
The CometChatQuickView widget is used to display a quick view with a title and an optional subtitle.
You can customize the appearance of the title and subtitle using the
titleTextStyleandsubtitleTextStyleparameters. - CometChatReactionList
- CometChatReactionList is a StatefulWidget that displays the list of reactions for a particular message. It requires reactionRequestBuilder to fetch the reactions of a particular message. It also requires message to fetch the reactions of a particular message. It also requires onTap to perform some action on click of a particular reaction.
- CometChatReactionListStyle
-
CometChatReactionListStyle is a class which is used to set the style for the reaction list
It takes
loadingStateColor, emptyTextStyle, errorTextStyle, subtitleTextStyle,width,height,background,gradient, border, borderRadius as a parameter - CometChatReactions
- CometChatReactions is a widget which is used to set the reactions It takes reactionList, theme, alignment, onReactionTap, onReactionLongPress, style as a parameter
- CometChatReactionsStyle
-
CometChatReactionsStyle is a class which is used to set the style for the reactions
It takes emojiTextStyle, countTextStyle,
width,height,background,gradient, border, borderRadius as a parameter - CometChatReceipt
-
CometChatReceipt is a widget that indicates the delivery status of a message
by default, a single tick mark indicates a message has been sent
a double tick mark indicates a message has been delivered
a double tick mark of color
cometChatTheme.palette.primaryindicates a message has been read - CometChatReceiptType
- CometChatReceiverType
-
CometChatSearchListController<
T1, T2> - An abstract class which holds the logic for searching in different lists
-
CometChatSearchListControllerProtocol<
T1> - CometChatShimmerEffect
- CometChatSingleSelect
- A Flutter widget for creating a single select element with multiple options.
- CometChatSingleSelectButton
- CometChatSpacing
- CometChatSpacing is a class that holds the spacing values for the CometChat UI Kit.
- CometChatStartConversationType
-
CometChatStartConversationType is a utility class that stores String constants of the types of
CometChatContacts - CometChatStatusIndicator
- CometChatStatusIndicator is a widget that is used to indicate the online status of a User
- CometChatStatusIndicatorStyle
- CometChatStatusIndicatorStyle is a data class that has styling-related properties to customize the appearance of CometChatStatusIndicator
- CometChatStickerBubbleStyle
- CometChatStickerBubbleStyle is a data class that has styling-related properties fo CometChatStickerBubble
- CometChatStreamBubble
- Renders an in-progress streaming AI response with shimmer effect.
- CometChatStreamCallBackEvents
- CometChatStreamService
- Manages real-time AI response streaming with event queues, delta buffers, and reconnect handling.
- CometChatSubscriptionType
- CometChatTextBubble
- CometChatTextBubble is a widget that gives text bubble
- CometChatTextBubbleStyle
- CometChatTextBubbleStyle is a data class that has styling-related properties to customize the appearance of CometChatTextBubble
- CometChatTextFormatter
- CometChatTextFormatter is an abstract class which is used to format the text It has properties like trackingCharacter, pattern, onSearch, showLoadingIndicator, messageBubbleTextStyle, messageInputTextStyle It has methods like init, handlePreMessageSend, onScrollToBottom, buildInputFieldText, mergeAttributedText, getAttributedText, onChange, getLoadingIndicator, getMessageInputTextStyle, getMessageBubbleTextStyle
- CometChatTextStyleBody
- CometChatTextStyleBody is a class that gives the styling to the text displayed in the body
- CometChatTextStyleButton
- CometChatTextStyleButton is a class that gives the styling to the text displayed in the buttons
- CometChatTextStyleCaption1
- CometChatTextStyleCaption1 is a class that gives the styling to the text displayed in the caption
- CometChatTextStyleCaption2
- CometChatTextStyleCaption2 is a class that gives the styling to the text displayed in the caption2
- CometChatTextStyleHeading1
- CometChatTextStyleHeading1 is a class that gives the styling to the text displayed in the heading1
- CometChatTextStyleHeading2
- CometChatTextStyleHeading2 is a class that gives the styling to the text displayed in the heading3
- CometChatTextStyleHeading3
- CometChatTextStyleHeading3 is a class that gives the styling to the text displayed in the heading3
- CometChatTextStyleHeading4
- CometChatTextStyleHeading4 is a class that gives the styling to the text displayed in the CometChatApp.
- CometChatTextStyleLink
- CometChatTextStyleLink is a class that gives the styling to the text displayed in the link
- CometChatTextStyleTitle
- CometChatTextStyleTitle is a class that gives the styling to the text displayed in the title
- CometChatTheme
- CometChatThemeHelper
- CometChatThemeHelper is a class that gives the styling to the text displayed in the buttons
- CometChatThemeMode
- CometChatTimeSlotSelector
- CometChatTypingIndicatorStyle
-
CometChatTypingIndicatorStyle is a style class that has styling-related properties for typing indicator
to customize the appearance of
CometChatTypingIndicator - CometChatTypography
- CometChatUIEvents
- CometChatUIKit
- CometChatUIKitHelper
- CometChatUIKitHelper contains static methods for triggering local events
- CometChatUrlFormatter
- CometChatUrlFormatter is a class which is used to style the url text
- CometChatUserEvents
- CometChatUserStatus
- CometChatVideoBubble
- CometChatVideoBubble creates a widget that gives video bubble
- CometChatVideoBubbleStyle
- CometChatVideoBubbleStyle is a data class that has styling-related properties to customize the appearance of CometChatVideoBubble
- CometChatWebView
- CometChatWebView is widget that renders a WebView
- CometChatWSState
- ComposerHeightNotifier
- Notifier for tracking message composer height
- Conversation
- Represents a chat conversation.
- ConversationOptionConstants
- ConversationOptionConstants is a utility class that stores String constants of options available for Conversation items
- ConversationsRequest
- A request object for fetching conversations.
- ConversationsRequestBuilder
-
Builder class for
ConversationsRequest. - ConversationType
- ConversationUpdateSettings
- ConversationUtils
- ConversationUtils is an Utility class that helps to the last message for any conversation and also provides the default action to execute on a conversation
- CurrentUser
- Represents the currently authenticated user.
- CustomAction
- Represents a custom action in a chat application.
- CustomInteractiveMessage
- Represents a message that includes various types of messages for interactive elements.
- CustomMessage
- Represents a custom chat message.
-
CustomPopupMenuItem<
T> - CustomStateView
- CustomTextEditingController
- DashOffset
- DateTimeElement
- Represents a dropdown model class , used to draw dropdown .
- DateTimeElementStyle
- DateTimeFormatterCallback
- DaySchedule
- Debouncer
- DecoratedContainerStyle
- DefaultBubbleFactories
- Utility class providing default bubble factories for all message types.
- DeletedBubbleFactory
- Factory for creating deleted message bubbles.
- DeleteMessageUseCase
- Delete message use case Handles message deletion with validation
- DetailsTemplateConstants
- DetailsTemplateConstants is a utility class that stores String constants of the types of CometChatDetailsTemplate
- DetailUtils
-
DetailUtils is a Utility class that provides
the default options and templates available in
CometChatDetailswhich allows users to block and unblock other users group members to view, add, ban other members - DottedBorder
- DropdownElement
- Represents a dropdown model class , used to draw dropdown .
- DropDownElementStyle
- ElementEntity
- EmojiUtils
- Utility for detecting emoji-only messages and determining display sizes.
- EmptyMessageList
- Empty state widget shown when there are no messages
- ErrorCode
- ErrorConstants
- ErrorMessage
- EventHandler
- ExtensionType
- Failure
- Failure state that can be returned from any Result
- FileBubbleFactory
- Factory for creating file message bubbles.
- FileConstants
- FileSizeCheckUtil
- FileUtils
- FlagDetail
- FlagReason
- Formatter
- FormatterUtils
- FormatterUtils is an utility class which is used to style the text in the message bubble and the conversation subtitle
- FormMessage
- Represents a message that includes a form with interactive elements.
- GetAudioStateStreamUseCase
- Use case to get audio state stream
- GetAudioStateUseCase
- Use case to get audio state
- GetMenuView
- GetPlayStateUseCase
- Use case to get current play state
- GetUnreadCountUseCase
- Get unread count use case
- Group
- Represents a group within the chat.
- GroupDataSource
- Abstract data source for group operations
- GroupDataSourceImpl
- CometChat SDK implementation of GroupDataSource
- GroupEntity
- Domain entity representing a chat group Pure Dart model with no dependencies on CometChat SDK
- GroupMapper
- Mapper to convert CometChat SDK Group to GroupEntity
- GroupMember
- Represents a group member within the chat.
- GroupMemberOptionConstants
- GroupMemberOptionConstants is a utility class that stores String constants of the actions permitted to a GroupMember to execute on a particular Group
- GroupMemberScope
- GroupMemberScope is a utility class that stores String constants of scope of GroupMember with respect to a particular Group
- GroupMembersRequest
- A request object for fetching group members.
- GroupMembersRequestBuilder
-
Builder class for
GroupMembersRequest. - GroupOptionConstants
-
GroupOptionConstants is a utility class that stores String constants of the options available in
CometChatDetailsif it is being rendered for a Group - GroupPreferences
- GroupRepository
- Abstract repository for group operations
- GroupRepositoryImpl
- Implementation of GroupRepository using SDK data source
- GroupsRequest
- A request object for fetching groups.
- GroupsRequestBuilder
-
Builder class for
GroupsRequest. - GroupTypeConstants
- GroupTypeConstants is a utility class that stores String constants of the types of Group
- IDMapConstants
- ImageBubbleFactory
- Factory for creating image message bubbles.
- ImageViewer
- Gives Full Screen image view for passed image url
- Interaction
- Represents an interaction within the chat.
- InteractionGoal
- Represents an interaction goal within the chat.
- InteractionGoalType
- InteractionGoalTypeConstants
- InteractionReceipt
- Represents an interaction receipt within the chat.
- InteractiveMessage
- Represents a interactive message within the chat.
- InteractiveMessageConstants
- InteractiveMessageUtils
- LabelElement
- Represents a label model class , used to draw label .
- ListBaseStyle
- ListBaseStyle is a data class that has styling-related properties to customize the appearance of CometChatListBase
- ListItemStyle
- ListItemStyle is a data class that has styling-related properties to customize the appearance of CometChatListItem
- LiveReactionConstants
- LiveReactionConstants is a utility class that stores constant values related to functioning of TransientMessage
- LoadMoreIndicator
- A loading indicator shown during pagination
- LoadMoreNotifier
- Notifier for tracking loading state during pagination
- LoggerConfig
- Immutable configuration for SDK logging.
- MarkdownTextFormatter
- A single unified formatter that parses all markdown syntax for message bubble display.
- MarkMessagesAsReadUseCase
- Mark messages as read use case
- MediaMessage
- Represents a media message within the chat.
- MediaPicker
- MessageCategoryConstants
- MessageCategoryConstants is a utility class that stores String constants of categories of messages
- MessageComposerSuggestions
- MessageDataSource
- Abstract data source for message operations Wraps CometChat SDK calls with error handling
- MessageDataSourceImpl
- CometChat SDK implementation of MessageDataSource
- MessageEntity
- Domain entity representing a chat message Pure Dart model with no dependencies on CometChat SDK
- MessageListEmpty
- Empty state - no messages found
- MessageListError
- Error state - operation failed
- MessageListInitial
- Initial state - before any operation
- MessageListLoading
- Loading state - while fetching data
- MessageListLoadingMore
- Pagination state - loading more messages
- MessageListMessageDeleted
- Message deleted state
- MessageListMessageSent
- Message sent state
- MessageListSearching
- Search state - searching for messages
- MessageListSearchResults
- Search results state
- MessageListSending
- Message sending state
- MessageListSuccess
- Success state - data loaded successfully
- MessageMapper
- Mapper to convert CometChat SDK BaseMessage to MessageEntity
- MessageOptionConstants
- MessageOptionConstants is a utility class that stores String constants of the actions permitted to execute on a particular BaseMessage
- MessageReceipt
- Represents a message receipt within the chat.
- MessageReceiptUtils
- MessageReceiptUtils is a utility class to determine receipt status
- MessageRepository
- Abstract repository for message operations Defines contract for message-related use cases
- MessageRepositoryImpl
- Implementation of MessageRepository using SDK data source
- MessagesRequest
- A request object for fetching messages.
- MessagesRequestBuilder
-
Allows step-by-step creation of an
MessagesRequestobject. - MessageTemplateUtils
- MessageTemplateUtils provides default templates to construct message bubbles and the default set of options for each bubble type.
- MessageTypeConstants
- MessageTypeConstants is a utility class that stores String constants of types of messages
- MessageUtils
- A utility class for message related operations. This class contains methods required for message related operations. It is used to get the message bubble, message time, and message receipt icon.
- MetadataConstants
-
MetadataConstants is a utility class that stores String constants to use in the
metadataproperty of a BaseMessage - ModelFieldConstants
- ModerationCheckUtil
- MutedConversation
- MutePreferences
- NetworkUtils
- NoIntrinsicScroll
- A widget that blocks intrinsic measurement from its child.
- NotificationCategoriesRequest
- A request object for fetching notification categories.
- NotificationCategoriesRequestBuilder
-
Builder class for
NotificationCategoriesRequest. - NotificationCategory
- Represents a notification category used for filtering notification feed items.
- NotificationFeedItem
- Represents a notification feed item within the CometChat notification feed.
- NotificationFeedRequest
- A request object for fetching notification feed items.
- NotificationFeedRequestBuilder
-
Builder class for
NotificationFeedRequest. - NotificationPreferences
- OneOnOnePreferences
- OptionElement
- PauseAllExceptUseCase
- Use case to pause all except specified
- PauseAudioUseCase
- Use case to pause audio
- PickedFile
- PlayAudioUseCase
- Use case to play audio
- PushNotification
- Represents a push notification payload for engagement tracking.
- QueueCompletionCallback
- QuickViewStyle
- A class representing styling options for a Quick View widget.
- RadioButtonElement
- Represents a radio button model class , used to draw radio button .
- RadioButtonElementStyle
- Reaction
- Represents a reaction within the chat.
- ReactionAction
- ReactionConstants
- ReactionCount
- Represents a count of reactions within the chat.
- ReactionEvent
- ReactionsRequest
- A request object for fetching reactions.
- ReactionsRequestBuilder
-
Builder class for
ReactionsRequest. - ReceiptTypeConstants
- ReceiptTypeConstants is a utility class that stores String constants of the various stages of message delivery
- ReceiverTypeConstants
- ReceiverTypeConstants is a utility class that stores String constants of the types of AppEntity that can receive a BaseMessage
- RegexConstants
- RegexConstants is a utility contains patterns or verifying selective text inputs
- RemoveAudioStateUseCase
- Use case to remove audio state
- ReplyUtils
- Utility for validating that a quoted message belongs to the current conversation.
- RequestBuilderConstants
-
Result<
T> - Generic Result wrapper for handling success and failure states Following the Either pattern for functional error handling
- SchedulerConstants
- SchedulerMessage
- SchedulerUtils
- ScrollToBottomButton
- A floating action button that appears when the user scrolls away from the bottom
- SDKMethods
- SearchMessagesParams
- SearchMessagesUseCase
- Search messages use case Searches messages with query validation
- SectionSeparator
- SeekAudioUseCase
- Use case to seek audio
- SendMessageParams
- SendMessageUseCase
- Send message use case Handles message sending with validation and error handling
- SetSourceConstant
- Service Locator for clean architecture dependency injection
- SingleSelectElement
- Represents a single select element model class used to create a single select input element.
- SingleSelectStyle
- A class representing styling options for a single select element.
- SliverSpacing
- A sliver that provides dynamic spacing at the bottom of the message list
- SnackBarConfiguration
- SnackBarUtils
- SoundManager
- SoundManager is an utility component that provides an audio player
- StatusIndicatorUtils
- StopAllAudioUseCase
- Use case to stop all audio
- StopAudioUseCase
- Use case to stop audio
- StreamEntity
- Stream Entity - Domain Model Represents a stream in the domain layer Pure data class with no external dependencies
- StreamMessage
- Represents a stream message in the chat.
- StreamStatusUpdate
- Detailed stream status update entity
-
Success<
T> - Success state containing the data
- SuggestionListItem
- SuggestionListItem is a modal class used to define the structure of the list item used in the suggestions list.
- SvgAssetConstants
- SvgAssetConstants is a utility class that stores String constants of asset image paths
- SwipeTile
- SwipeTile is stacked widget which can take a child widget as input upon pressing that child widget down and sliding it to the left menu items are revealed
- SwipeTileOptions
- TextBubbleFactory
- Factory for creating text message bubbles.
- TextInputElement
- Represents a text input model class , used to draw text input element .
- TextInputElementStyle
- TextInputPlaceholder
- placeholder model for Text field
- TextMessage
- Represents a text message within the chat.
- ThumbnailExtractionUtil
-
Utility for extracting thumbnail URLs from a message's metadata,
typically populated by the CometChat
thumbnail-generationextension for image and video attachments. - TimeRange
- TimeSlotSelectorStyle
- TransientMessage
- Represents a temporary or transient message within the chat.
- Translations
- TranslationsAr
-
The translations for Arabic (
ar). - TranslationsDe
-
The translations for German (
de). - TranslationsEn
-
The translations for English-us (
en). - TranslationsEnGb
-
The translations for English-uk(
en_GB). - TranslationsEs
-
The translations for Spanish Castilian (
es). - TranslationsFr
-
The translations for French (
fr). - TranslationsHi
-
The translations for Hindi (
hi). - TranslationsHu
-
The translations for Hungarian (
hu). - TranslationsJa
-
The translations for Japanese (
ja). - TranslationsKo
-
The translations for Korean (
ko). - TranslationsLt
-
The translations for Lithuanian (
lt). - TranslationsMs
-
The translations for Malay (
ms). - TranslationsNl
-
The translations for Dutch (
nl). - TranslationsPt
-
The translations for Portuguese (
pt). - TranslationsRu
-
The translations for Russian (
ru). - TranslationsSv
-
The translations for Swedish (
sv). - TranslationsTr
-
The translations for Turkish (
tr). - TranslationsZh
-
The translations for Chinese (
zh). - TranslationsZhTw
-
The translations for Chinese, as used in Taiwan (
zh_TW). - TypingIndicator
- Represents a typing indicator within the chat.
- UIConstants
- UIConstants contains properties essential and limited to setting up the ui kit
- UIElementTypeConstants
- UIEventHandler
- UIEventUtils
- UIKitSettings
- Used to set Ui kit level settings
- UIKitSettingsBuilder
- Builder class for UIKitSettings
- UIStateUtils
- UITabNameConstants
-
UITabNameConstants is a utility class that stores String constants of the names of the tabs available for
CometChatUI - UnmutedConversation
- UnreadCountError
- UnreadCountInitial
- UnreadCountLoading
- UnreadCountState
- State for unread count
- UnreadCountSuccess
- UpdateSettingsConstant
- Represents an action for URL navigation within a chat application.
-
UseCase<
Type, Params> - Base use case class All use cases should extend this class
- User
- Represents a user within the chat.
- UserDataSource
- Abstract data source for user operations
- UserDataSourceImpl
- CometChat SDK implementation of UserDataSource
- UserEntity
- Domain entity representing a chat user Pure Dart model with no dependencies on CometChat SDK
- UserMapper
- Mapper to convert CometChat SDK User to UserEntity
- UserOptionConstants
-
UserOptionConstants is a utility class that stores String constants of the options available in
CometChatDetailsif it is being rendered for a User - UserPresence
- Represents user presence information from WebSocket events.
- UserRepository
- Abstract repository for user operations
- UserRepositoryImpl
- Implementation of UserRepository using SDK data source
- UsersRequest
- A request object for fetching users.
- UsersRequestBuilder
-
Builder class for
UsersRequest. - UserStatusConstants
- UserStatusConstants is a utility class that stores String constants of the online/offline status of an User
- Utils
- VideoBubbleFactory
- Factory for creating video message bubbles.
- VideoPlayer
- Gives Full screen video player for CometChatVideoBubble
- WebViewStyle
- WidgetPositionUtil
Enums
- ActivateSelection
- ActivateSelection is an enum that controls on what gesture selection will work
- APIActionMethod
- AttachmentType
- AudioBubbleActions
- AuxiliaryButtonsAlignment
- AuxiliaryButtonsAlignment is an enum that defines the position of the auxiliary buttons in the CometChatMessageComposer
- BubbleAlignment
- BubbleAlignment is an enum that defines the alignment of the messag bubble
- ChatAlignment
- ChatAlignment is an enum that defines the alignment of the messages in the message list
- CometChatComposerLayout
- CometChatComposerLayout controls the skeleton layout of CometChatMessageComposer.
- ConversationTypes
- ConversationTypes is an enum that is used fetch filtered Conversation list
- CustomUIPosition
- DateTimePattern
- DateTimeVisibilityMode
- DayOfWeek
- DNDOptions
- EventStatus
-
EventStatus is an enum that contains the various stages of deleting a message
inProgress means the request to delete a BaseMessage is currently ongoing or has been made but awaiting success response
success means message was deleted successfully and a success response has been received in the
onSuccesscallback for the request to delete a BaseMessage - FeedReadState
-
Type-safe enum for filtering feed items by read state in
NotificationFeedRequestBuilder.setReadState(). - FileType
- InitialScrollToEndMode
- Enum controlling the initial scroll behavior of the message list
- LiveReactionType
-
Listener class for
CometChatMessages - LogLayer
- Layers of the SDK that can have logging enabled/disabled independently.
- MemberActionsOptions
- MentionsType
- MentionsVisibility
- MessageEditStatus
-
MessageEditStatus is an enum that contains the various stages of updating a messag
inProgress means the request to update a BaseMessage is currently ongoing or has been made but awaiting success response
success means message was updated successfully and a success response has been received in the
onSuccesscallback for the request to update a BaseMessage - MessagesOptions
- MessageStatus
- Enum for message status
- MessageType
- Enum for message types
- ModerationStatusEnum
- MutedConversationType
- PlayState
- Domain Layer - Audio State Entity Represents the state of an audio bubble playback
- PreviewMessageMode
- PreviewMessageMode is an enum that defines the nature of the message preview that needs to be shown in the CometChatMessageComposer
- PushPlatforms
- ReactionsOptions
- ReceiptStatus
- RepliesOptions
- SchedulerBubbleStage
- ScheduleStatus
- SelectionMode
- SelectionMode is an enum that defines how many items can be selected in a list
- SortByOrderEnum
- Sound
- StreamPlaybackStatus
- Enum for stream playback status
- TabVisibility
- TimeAlignment
- TimeAlignment is an enum that defines the position of the timestamp shown in the message bubble top places the timestamp in the header of CometChatMessageBubble bottom places the timestamp in the footer of CometChatMessageBubble
- TimeFormat
Mixins
- AIAssistantListener
- CallListener
- CallListener2
- CometChatAIAssistantEventsListener
- CometChatCallEventListener
- Listener class for CometChatCallEvents
- CometChatConversationEventListener
- Listener class for CometChatConversations
- CometChatConversationsControllerProtocol
- CometChatGroupEventListener
- Events can be triggered by Group Module e.g. Clicking on a particular group. All public-facing components in each module will trigger events.
-
CometChatListProtocol<
T1> - Marker class to state predefined methods for CometChatList
- CometChatMessageEventListener
-
CometChatSelectable<
T1, T2> - An mixin to hold common logic for selecting list item
- CometChatStreamCallbackListener
- CometChatUIEventListener
- Listener class for CometChatConversations
- CometChatUserEventListener
- Events can be triggered by the user action for e.g. Clicking on a particular user item. All public-facing components in each module will trigger events.
- ConnectionListener
- GroupListener
-
KeyboardMixin<
T extends StatefulWidget> - Mixin for detecting keyboard height changes
-
KeyIdentifier<
T, T2> - Abstract class to get the key in case of searching
- LoginListener
- MessageListener
- NotificationFeedListener
- Listener for real-time notification feed events.
- UserListener
Extensions
- BubbleUIBuilder on MessageUtils
- the following extension BubbleUIBuilder is used to build the UI of the message bubbles.
- CometChatAssetConstants on AssetConstants
- CometChatAssetConstants is an extension that provides asset image paths according to the brightness mode of the device
-
DateTimeExtension
on DateTimeRange<
DateTime> - DateTimeExtension2 on DateTime
- MessageStatusExt on MessageStatus
- Extension methods for MessageStatus
- MessageTypeExt on MessageType
- Extension methods for MessageType
-
ResultExtension
on Result<
T> - Helper extension to simplify Result handling
- StringFormatUtils on String
-
TimeStampGeneration
on List<
DateTime>
Constants
-
kCometChatSupportedLanguage
→ const Set<
String> -
Callers can lookup localized strings with an instance of Translations
returned by
Translations.of(context).
Properties
- cometchatConstantString ↔ String
-
getter/setter pair
Functions
-
cast<
T> (dynamic x) → T? -
lookupTranslations(
Locale locale) → Translations -
showCometChatAiOptionSheet(
{required BuildContext context, required List< CometChatMessageComposerAction> actionItems, User? user, Group? group, CometChatColorPalette? colorPalette, CometChatTypography? typography, CometChatSpacing? spacing, CometChatAiOptionSheetStyle? style, AIOptionsStyle? aiOptionStyle}) → Future<CometChatMessageComposerAction?> ? - Shows a bottom sheet listing available AI actions.
-
showCometChatAttachmentOptionSheet(
{required BuildContext context, required List< ActionItem> actionItems, required CometChatColorPalette colorPalette, CometChatAttachmentOptionSheetStyle? style}) → Future<ActionItem?> ? - Shows a bottom sheet with a list of options to choose from. Returns the selected ActionItem when an option is selected.
-
showLoadingIndicatorDialog(
BuildContext context, {Color? background, Color? shadowColor, Color? progressIndicatorColor}) → dynamic
Typedefs
- AIAssistantToolEventResult = AIAssistantToolResultEvent
- Deprecated alias for AIAssistantToolResultEvent.
- BubbleViewProvider = Widget? Function(BuildContext context, BaseMessage message, BubbleAlignment alignment)
- Callback for providing custom views for message bubble slots. Returns Widget or null to use default/hide.
-
ComposerActionsBuilder
= List<
CometChatMessageComposerAction> Function(BuildContext context, User? user, Group? group, Map<String, dynamic> ? id) -
ComposerWidgetBuilder
= Widget Function(BuildContext context, User? user, Group? group, Map<
String, dynamic> ? id) - EmptyMessageListBuilder = Widget Function(BuildContext context)
- Builder type for custom empty state widget
- LoadMoreBuilder = Widget Function(BuildContext context)
- Builder type for custom load more indicator
- OnEmpty = void Function()
- OnEmpty defines the structure of empty handler used by the components in the ui kit
- OnError = dynamic Function(Exception e)
- OnError defines the structure of error handler used by the components in the ui kit
-
OnLoad<
T> = dynamic Function(List< T> list) - OnLoad defines the structure of loading handler used by the components in the ui kit
-
ScrollToBottomBuilder
= Widget Function(BuildContext context, Animation<
double> animation, VoidCallback onPressed) - Builder type for custom scroll-to-bottom button
- UserGroupBuilder = dynamic Function(BuildContext context, User? user, Group? group)
Exceptions / Errors
- AppException
- Base exception for clean architecture
- CometChatException
- CometChatListException
- Generic exception class to replace SDK-specific exceptions
- LocalException
- Exception from local storage
- RemoteException
- Exception from remote API/SDK
- UnknownException
- Unknown/unexpected exception
- ValidationException
- Exception from invalid input