MessageMapper class

Mapper to convert CometChat SDK BaseMessage to MessageEntity

Constructors

MessageMapper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromSDK(dynamic message) MessageEntity
Convert SDK BaseMessage to domain MessageEntity Note: Adjust property names based on actual SDK BaseMessage interface
fromSDKList(List messages) List<MessageEntity>
Convert list of SDK messages to domain entities