shared_ui/src/clean_architecture/presentation/theme/theme library

Classes

CometChatColorHelper
The CometChatColorHelper class provides methods to blend two colors together and generate a color palette based on the base color and blend color provided.
CometChatColorPalette
The CometChatColorPalette class provides a color palette for the CometChat UI Kit.
CometChatSpacing
CometChatSpacing is a class that holds the spacing values for the CometChat UI Kit.
CometChatTextStyleBody
CometChatTextStyleBody is a class that gives the styling to the text displayed in the body
CometChatTextStyleButton
CometChatTextStyleButton is a class that gives the styling to the text displayed in the buttons
CometChatTextStyleCaption1
CometChatTextStyleCaption1 is a class that gives the styling to the text displayed in the caption
CometChatTextStyleCaption2
CometChatTextStyleCaption2 is a class that gives the styling to the text displayed in the caption2
CometChatTextStyleHeading1
CometChatTextStyleHeading1 is a class that gives the styling to the text displayed in the heading1
CometChatTextStyleHeading2
CometChatTextStyleHeading2 is a class that gives the styling to the text displayed in the heading3
CometChatTextStyleHeading3
CometChatTextStyleHeading3 is a class that gives the styling to the text displayed in the heading3
CometChatTextStyleHeading4
CometChatTextStyleHeading4 is a class that gives the styling to the text displayed in the CometChatApp.
CometChatTextStyleLink is a class that gives the styling to the text displayed in the link
CometChatTextStyleTitle
CometChatTextStyleTitle is a class that gives the styling to the text displayed in the title
CometChatTheme
CometChatThemeHelper
CometChatThemeHelper is a class that gives the styling to the text displayed in the buttons
CometChatThemeMode
CometChatTypography