shared_ui/src/cometchat_list/builder_protocol library

Classes

BuilderProtocol<T1, T2>
BuilderProtocol is the Marker class to define protocols Used to generate different request builders T1 is the type of Request builder to be passed and T2 should be the respective request type eg for user list T1 will be UsersRequestBuilder and T2 will be UsersRequest