OnEmpty typedef
OnEmpty =
void Function()
OnEmpty defines the structure of empty handler used by the components in the ui kit
Implementation
typedef OnEmpty = void Function();
OnEmpty defines the structure of empty handler used by the components in the ui kit
typedef OnEmpty = void Function();