isBlockElement property
isBlockElement indicates if this is a block-level element (like code block or blockquote) Block elements should take full width and have distinct visual styling
Implementation
bool isBlockElement;
isBlockElement indicates if this is a block-level element (like code block or blockquote) Block elements should take full width and have distinct visual styling
bool isBlockElement;