padding property
padding is a EdgeInsetsGeometry object which is used to give padding to the text
Implementation
EdgeInsetsGeometry? padding;
padding is a EdgeInsetsGeometry object which is used to give padding to the text
EdgeInsetsGeometry? padding;