shared_ui/src/formatter/cometchat_text_formatter library
Classes
- CometChatTextFormatter
- CometChatTextFormatter is an abstract class which is used to format the text It has properties like trackingCharacter, pattern, onSearch, showLoadingIndicator, messageBubbleTextStyle, messageInputTextStyle It has methods like init, handlePreMessageSend, onScrollToBottom, buildInputFieldText, mergeAttributedText, getAttributedText, onChange, getLoadingIndicator, getMessageInputTextStyle, getMessageBubbleTextStyle