shared_ui/src/keyboard_height/keyboard_height_plugin library

Classes

KeyboardHeightInfo
Data class for keyboard height info from native.
KeyboardHeightPlugin
A plugin that provides keyboard height before the keyboard animation occurs.

Typedefs

KeyboardHeightCallback = void Function(double keyboardHeight, double safeAreaBottom)
Callback type for keyboard height changes. Receives keyboard height and safe area bottom in logical pixels.