KeyboardHeightInfo class

Data class for keyboard height info from native.

Constructors

KeyboardHeightInfo({required double keyboardHeight, required double safeAreaBottom})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
keyboardHeight double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safeAreaBottom double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited