AudioBubbleEvents class
Constructors
- AudioBubbleEvents({required int id, required AudioBubbleActions action})
Properties
- action → AudioBubbleActions
-
action action to be performed
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
id message object id to make file name unique
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited