actionBubbleStyle property
actionBubbleStyle is a CometChatActionBubbleStyle that can be used to style action bubble
Implementation
final CometChatActionBubbleStyle? actionBubbleStyle;
actionBubbleStyle is a CometChatActionBubbleStyle that can be used to style action bubble
final CometChatActionBubbleStyle? actionBubbleStyle;