attachmentOptionSheetStyle property
attachmentOptionSheetStyle is a CometChatAttachmentOptionSheetStyle that can be used to style attachment option sheet
Implementation
final CometChatAttachmentOptionSheetStyle? attachmentOptionSheetStyle;
attachmentOptionSheetStyle is a CometChatAttachmentOptionSheetStyle that can be used to style attachment option sheet
final CometChatAttachmentOptionSheetStyle? attachmentOptionSheetStyle;