audioBubbleStyle property
audioBubbleStyle is a CometChatVoiceNoteBubbleStyle that can be used to style audio bubble
Implementation
final CometChatVoiceNoteBubbleStyle? audioBubbleStyle;
audioBubbleStyle is a CometChatVoiceNoteBubbleStyle that can be used to style audio bubble
final CometChatVoiceNoteBubbleStyle? audioBubbleStyle;