callButtonsStyle property
callButtonsStyle is a CometChatCallButtonsStyle that can be used to style call buttons
Implementation
final CometChatCallButtonsStyle? callButtonsStyle;
callButtonsStyle is a CometChatCallButtonsStyle that can be used to style call buttons
final CometChatCallButtonsStyle? callButtonsStyle;