collaborativeDocumentBubbleStyle property
collaborativeDocumentBubbleStyle provides style to the collaborative document bubble of the sent message
Implementation
final CometChatCollaborativeBubbleStyle? collaborativeDocumentBubbleStyle;
collaborativeDocumentBubbleStyle provides style to the collaborative document bubble of the sent message
final CometChatCollaborativeBubbleStyle? collaborativeDocumentBubbleStyle;