collaborativeWhiteboardBubbleStyle property
collaborativeWhiteboardBubbleStyle provides style to the collaborative whiteboard bubble of the sent message
Implementation
final CometChatCollaborativeBubbleStyle? collaborativeWhiteboardBubbleStyle;
collaborativeWhiteboardBubbleStyle provides style to the collaborative whiteboard bubble of the sent message
final CometChatCollaborativeBubbleStyle? collaborativeWhiteboardBubbleStyle;