deletedBubbleStyle property
deletedBubbleStyle is a CometChatDeletedBubbleStyle that can be used to style deleted bubble
Implementation
final CometChatDeletedBubbleStyle? deletedBubbleStyle;
deletedBubbleStyle is a CometChatDeletedBubbleStyle that can be used to style deleted bubble
final CometChatDeletedBubbleStyle? deletedBubbleStyle;