fileBubbleStyle property
fileBubbleStyle is a CometChatFileBubbleStyle that can be used to style file bubble
Implementation
final CometChatFileBubbleStyle? fileBubbleStyle;
fileBubbleStyle is a CometChatFileBubbleStyle that can be used to style file bubble
final CometChatFileBubbleStyle? fileBubbleStyle;