hideAudioAttachmentOption property
hideAudioAttachmentOption is a bool that can be used to hide/display audio attachment option
Implementation
final bool? hideAudioAttachmentOption;
hideAudioAttachmentOption is a bool that can be used to hide/display audio attachment option
final bool? hideAudioAttachmentOption;