hideCollaborativeWhiteboardOption property
hideCollaborativeWhiteboardOption is a bool that can be used to hide/display collaborative whiteboard option
Implementation
final bool? hideCollaborativeWhiteboardOption;
hideCollaborativeWhiteboardOption is a bool that can be used to hide/display collaborative whiteboard option
final bool? hideCollaborativeWhiteboardOption;