hideCopyMessageOption property
hideCopyMessageOption This prop defines whether a user can copy message or not.
Implementation
final bool? hideCopyMessageOption;
hideCopyMessageOption This prop defines whether a user can copy message or not.
final bool? hideCopyMessageOption;