hideDeleteMessageOption property
hideDeleteMessageOption This prop defines whether Delete Message option should be visible or not.
Implementation
final bool? hideDeleteMessageOption;
hideDeleteMessageOption This prop defines whether Delete Message option should be visible or not.
final bool? hideDeleteMessageOption;