hideEditMessageOption property
hideEditMessageOption This prop defines whether Edit Message option should be visible or not.
Implementation
final bool? hideEditMessageOption;
hideEditMessageOption This prop defines whether Edit Message option should be visible or not.
final bool? hideEditMessageOption;