hideFileAttachmentOption property
hideFileAttachmentOption is a bool that can be used to hide/display file attachment option
Implementation
final bool? hideFileAttachmentOption;
hideFileAttachmentOption is a bool that can be used to hide/display file attachment option
final bool? hideFileAttachmentOption;