hideImageAttachmentOption property
hideImageAttachmentOption is a bool that can be used to hide/display image attachment option
Implementation
final bool? hideImageAttachmentOption;
hideImageAttachmentOption is a bool that can be used to hide/display image attachment option
final bool? hideImageAttachmentOption;