hideMessageInfoOption property
hideMessageInfoOption This prop defines whether a user can fetch information about the message whether it's received or not.
Implementation
final bool? hideMessageInfoOption;
hideMessageInfoOption This prop defines whether a user can fetch information about the message whether it's received or not.
final bool? hideMessageInfoOption;