hideMessagePrivatelyOption property

bool? hideMessagePrivatelyOption
final

hideMessagePrivatelyOption This prop defines whether a user can privately message other member of the group or not.

Implementation

final bool? hideMessagePrivatelyOption;