hideReactionOption property
hideReactionOption This prop defines whether Reaction option should be visible or not.
Implementation
final bool? hideReactionOption;
hideReactionOption This prop defines whether Reaction option should be visible or not.
final bool? hideReactionOption;