hideReplyOption property
hideReplyOption This prop defines whether the inline Reply option should be visible or not.
Implementation
final bool? hideReplyOption;
hideReplyOption This prop defines whether the inline Reply option should be visible or not.
final bool? hideReplyOption;