hideShareMessageOption property
hideShareMessageOption This prop defines whether share option should be visible or not.
Implementation
final bool? hideShareMessageOption;
hideShareMessageOption This prop defines whether share option should be visible or not.
final bool? hideShareMessageOption;