hideStickersButton property
hideStickersButton is a bool that can be used to hide/display sticker button
Implementation
final bool? hideStickersButton;
hideStickersButton is a bool that can be used to hide/display sticker button
final bool? hideStickersButton;