hideTranslateMessageOption property
hideTranslateMessageOption This prop defines whether Reply In Thread option should be visible or not.
Implementation
final bool? hideTranslateMessageOption;
hideTranslateMessageOption This prop defines whether Reply In Thread option should be visible or not.
final bool? hideTranslateMessageOption;