hideVideoAttachmentOption property
hideVideoAttachmentOption is a bool that can be used to hide/display video attachment option
Implementation
final bool? hideVideoAttachmentOption;
hideVideoAttachmentOption is a bool that can be used to hide/display video attachment option
final bool? hideVideoAttachmentOption;