hideVideoCallButton property
hideVideoCallButton is a bool that can be used to hide/display video call button
Implementation
final bool? hideVideoCallButton;
hideVideoCallButton is a bool that can be used to hide/display video call button
final bool? hideVideoCallButton;