hideVoiceCallButton property
hideVoiceCallButton is a bool that can be used to hide/display voice call button
Implementation
final bool? hideVoiceCallButton;
hideVoiceCallButton is a bool that can be used to hide/display voice call button
final bool? hideVoiceCallButton;