imageBubbleStyle property
imageBubbleStyle is a CometChatImageBubbleStyle that can be used to style image bubble
Implementation
final CometChatImageBubbleStyle? imageBubbleStyle;
imageBubbleStyle is a CometChatImageBubbleStyle that can be used to style image bubble
final CometChatImageBubbleStyle? imageBubbleStyle;