linkPreviewBubbleStyle property
linkPreviewBubbleStyle is a CometChatLinkPreviewBubbleStyle that can be used to style link preview bubble
Implementation
final CometChatLinkPreviewBubbleStyle? linkPreviewBubbleStyle;
linkPreviewBubbleStyle is a CometChatLinkPreviewBubbleStyle that can be used to style link preview bubble
final CometChatLinkPreviewBubbleStyle? linkPreviewBubbleStyle;