messageOptionSheetStyle property
messageOptionSheetStyle is a CometChatMessageOptionSheetStyle that can be used to style message option sheet
Implementation
final CometChatMessageOptionSheetStyle? messageOptionSheetStyle;
messageOptionSheetStyle is a CometChatMessageOptionSheetStyle that can be used to style message option sheet
final CometChatMessageOptionSheetStyle? messageOptionSheetStyle;