pollsBubbleStyle property
pollsBubbleStyle is a CometChatPollsBubbleStyle that can be used to style polls bubble
Implementation
final CometChatPollsBubbleStyle? pollsBubbleStyle;
pollsBubbleStyle is a CometChatPollsBubbleStyle that can be used to style polls bubble
final CometChatPollsBubbleStyle? pollsBubbleStyle;