stickerBubbleStyle property
stickerBubbleStyle is a CometChatStickerBubbleStyle that can be used to style sticker bubble
Implementation
final CometChatStickerBubbleStyle? stickerBubbleStyle;
stickerBubbleStyle is a CometChatStickerBubbleStyle that can be used to style sticker bubble
final CometChatStickerBubbleStyle? stickerBubbleStyle;