textBubbleStyle property
textBubbleStyle is a CometChatTextBubbleStyle that can be used to style text bubble
Implementation
final CometChatTextBubbleStyle? textBubbleStyle;
textBubbleStyle is a CometChatTextBubbleStyle that can be used to style text bubble
final CometChatTextBubbleStyle? textBubbleStyle;