videoBubbleStyle property
videoBubbleStyle is a CometChatVideoBubbleStyle that can be used to style video bubble
Implementation
final CometChatVideoBubbleStyle? videoBubbleStyle;
videoBubbleStyle is a CometChatVideoBubbleStyle that can be used to style video bubble
final CometChatVideoBubbleStyle? videoBubbleStyle;