videoCallBubbleStyle property
videoCallBubbleStyle is a CometChatCallBubbleStyle that can be used to style video call bubble
Implementation
final CometChatCallBubbleStyle? videoCallBubbleStyle;
videoCallBubbleStyle is a CometChatCallBubbleStyle that can be used to style video call bubble
final CometChatCallBubbleStyle? videoCallBubbleStyle;