voiceCallBubbleStyle property
voiceCallBubbleStyle is a CometChatCallBubbleStyle that can be used to style voice call bubble
Implementation
final CometChatCallBubbleStyle? voiceCallBubbleStyle;
voiceCallBubbleStyle is a CometChatCallBubbleStyle that can be used to style voice call bubble
final CometChatCallBubbleStyle? voiceCallBubbleStyle;