AIOptionsStyle class

Style for individual AI option items in the option sheet.

Inheritance

Constructors

AIOptionsStyle({Color? backgroundColor, Border? border, BorderRadiusGeometry? borderRadius, TextStyle? titleTextStyle, Color? titleColor, Color? iconColor})
const

Properties

backgroundColor Color?
final
border Border?
final
borderRadius BorderRadiusGeometry?
final
hashCode int
The hash code for this object.
no setterinherited
iconColor Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titleColor Color?
final
titleTextStyle TextStyle?
final
type Object
The extension's type.
no setterinherited

Methods

copyWith({Color? backgroundColor, Border? border, BorderRadiusGeometry? borderRadius, TextStyle? titleTextStyle, Color? titleColor, Color? iconColor}) AIOptionsStyle
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<AIOptionsStyle>? other, double t) AIOptionsStyle
Linearly interpolate with another ThemeExtension object.
override
merge(AIOptionsStyle? other) AIOptionsStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) AIOptionsStyle