shared_ui/src/rich_text_formatting/data/data library
Barrel export for data layer
Classes
- AttributedTextData
- Data representing a text segment with formatting attributes.
- BlockquoteFormatterDataSource
- Formatter data source for blockquotes using > text syntax.
- BoldFormatterDataSource
- Formatter data source for bold text using text syntax.
- BulletListFormatterDataSource
- Formatter data source for bullet lists using - item syntax.
- CodeBlockFormatterDataSource
-
Formatter data source for code blocks using
codesyntax. - FormatterDataSource
- Abstract interface for formatter data sources.
- FormatterResult
- Data layer result from applying a format operation.
- InlineCodeFormatterDataSource
-
Formatter data source for inline code using
codesyntax. - ItalicFormatterDataSource
- Formatter data source for italic text using text or text syntax.
- LinkFormatterDataSource
- Formatter data source for links using text syntax.
- OrderedListFormatterDataSource
- Formatter data source for ordered lists using 1. item syntax.
- RichTextRepositoryImpl
- Implementation of RichTextRepository that delegates to formatter data sources.
- StrikethroughFormatterDataSource
-
Formatter data source for strikethrough text using
textsyntax. - UnderlineFormatterDataSource
- Formatter data source for underlined text using syntax.