AIUtils class

Constructors

AIUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getEmptyView(BuildContext context, {Color? backgroundColor, Color? shadowColor, String? emptyIconUrl, String? emptyIconPackageName, String? emptyStateText, Color? emptyIconTint, TextStyle? emptyTextStyle}) Widget
getErrorText(BuildContext context, CometChatColorPalette colorPalette, CometChatTypography typography, CometChatSpacing spacing, {String? errorStateText, TextStyle? errorTextStyle}) Widget
getLoadingIndicator(BuildContext context, {Color? backgroundColor, Color? shadowColor, String? loadingIconUrl, String? loadingIconPackageName, String? loadingStateText, Color? loadingIconTint, TextStyle? loadingTextStyle}) Widget
getOnError(BuildContext context, {Color? backgroundColor, Color? shadowColor, String? errorIconUrl, String? errorIconPackageName, String? errorStateText, Color? errorIconTint, TextStyle? errorTextStyle}) Widget

Constants

extensionKey → const String