shared_ui/src/utils/conversation_utils library

Classes

ConversationUtils
ConversationUtils is an Utility class that helps to the last message for any conversation and also provides the default action to execute on a conversation