shared_ui/src/utils/detail_utils library

Classes

DetailUtils
DetailUtils is a Utility class that provides the default options and templates available in CometChatDetails which allows users to block and unblock other users group members to view, add, ban other members