shared_ui/src/utils/message_utils library

Classes

CometChatMessageBubbleStyleData
CometChatMessageBubbleStyleData is a model class which contains the style properties for the message bubble.
MessageUtils
A utility class for message related operations. This class contains methods required for message related operations. It is used to get the message bubble, message time, and message receipt icon.

Extensions

BubbleUIBuilder on MessageUtils
the following extension BubbleUIBuilder is used to build the UI of the message bubbles.