exceptionTextStyle property
exceptionTextStyle provides text style to the exception view warning text
Implementation
final TextStyle? exceptionTextStyle;
exceptionTextStyle provides text style to the exception view warning text
final TextStyle? exceptionTextStyle;