messageBubbleAvatarStyle property
messageBubbleAvatarStyle provides style to the avatar of the senderCometChatAvatarStyle? messageBubbleAvatarStyle;
Implementation
CometChatAvatarStyle? messageBubbleAvatarStyle;
messageBubbleAvatarStyle provides style to the avatar of the senderCometChatAvatarStyle? messageBubbleAvatarStyle;
CometChatAvatarStyle? messageBubbleAvatarStyle;