messageBubbleBackgroundImage property
messageBubbleBackgroundImage provides background image to the message bubble of a received message
Implementation
DecorationImage? messageBubbleBackgroundImage;
messageBubbleBackgroundImage provides background image to the message bubble of a received message
DecorationImage? messageBubbleBackgroundImage;