messageBubbleDateStyle property
messageBubbleDateStyle provides style to the date of the message bubble
Implementation
CometChatDateStyle? messageBubbleDateStyle;
messageBubbleDateStyle provides style to the date of the message bubble
CometChatDateStyle? messageBubbleDateStyle;