moderationTextStyle property
moderationTextStyle provides text style to the moderated view warning text
Implementation
final TextStyle? moderationTextStyle;
moderationTextStyle provides text style to the moderated view warning text
final TextStyle? moderationTextStyle;