threadedMessageIndicatorTextStyle property
threadedMessageIndicatorTextStyle provides text style to the threaded message indicator
Implementation
TextStyle? threadedMessageIndicatorTextStyle;
threadedMessageIndicatorTextStyle provides text style to the threaded message indicator
TextStyle? threadedMessageIndicatorTextStyle;