SDKMethods class

Constructors

SDKMethods()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

sendCardMessage(CardMessage message, {required dynamic onSuccess(CardMessage message)?, required dynamic onError(CometChatException excep)?}) Future<CardMessage?>
sendFormMessage(FormMessage message, {required dynamic onSuccess(FormMessage message)?, required dynamic onError(CometChatException excep)?}) Future<FormMessage?>
sendSchedulerMessage(SchedulerMessage message, {required dynamic onSuccess(SchedulerMessage message)?, required dynamic onError(CometChatException excep)?}) Future<SchedulerMessage?>