call_ui/src/call_logs/call_logs_builder_protocol library
Classes
- CallLogsBuilderProtocol
- CallLogsBuilderProtocol is an interface that defines the structure for fetching the callLogs. It provides a generic requestBuilder property and methods getRequest and getSearchRequest that needs to be overridden.
- UICallLogsBuilder
- UICallLogsBuilder is the default CallLogsBuilderProtocol used when a custom builder protocol is not passed