CallUtils class
CallUtils is a utility class that contains methods to perform call related operations.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
callLogLoggedInUser(
CallLog? callLog, User? loggedInUser) → bool - Returns true if the call is initiated by the logged in user.
-
getCallIcon(
BuildContext context, CallLog callLog, User? loggedInUser, CometChatColorPalette colorPalette, CometChatTypography typography, CometChatSpacing spacing, CometChatCallLogsStyle style, {Widget? incomingCallIcon, Widget? outgoingCallIcon, Widget? missedCallIcon}) → Widget - getCallIcon Return call status icon
-
getCallIconByStatus(
BuildContext context, BaseMessage baseMessage, User? loggedInUser, bool isAudio) → String -
getCallIconColor(
BuildContext context, BaseMessage baseMessage, User? loggedInUser, CometChatColorPalette colorPalette) → Color -
getCallStatus(
BuildContext context, BaseMessage baseMessage, User? loggedInUser) → String - Returns the call status message.
-
getCallStatusColor(
CallLog callLog, User? loggedInUser, CometChatColorPalette colorPalette) → Color - getCallStatusColor returns call status color
-
getCallTextColor(
BuildContext context, BaseMessage baseMessage, User? loggedInUser, CometChatColorPalette colorPalette) → Color -
getLastMessageForGroupCall(
BaseMessage lastMessage, BuildContext context, User? loggedInUser) → String -
getStatus(
BuildContext? context, CallLog? callLog, User? loggedInUser) → String - getStatus return call status
-
isAudioCall(
CallLog callLog) → bool -
isCallInitiatedByMe(
Call call) → bool -
isLoggedInUser(
User? initiator, User? loggedInUser) → bool - Returns true if the call is initiated by the logged in user.
-
isMissedCall(
Call call, User? loggedInUser) → bool - isMissedCall returns true if the call is missed call.
-
isVideoCall(
Call call) → bool - Returns true if the call is a video call.