ConversationSubtitleUtils class
Utility class for building conversation subtitle widgets. These methods are only used by the conversations module.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getConversationSubtitle(
Conversation conversation, BuildContext context, TextStyle? subtitleStyle, Color? iconColor, {AdditionalConfigurations? additionalConfigurations}) → Widget -
getLastConversationMessage(
Conversation conversation, BuildContext context) → String -
getLastConversationWidget(
Conversation conversation, BuildContext context, Color? iconColor) → Widget