CachedPreview class
Cached preview content
Constructors
Properties
- cachedAt → DateTime
-
final
- formattedText → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
final
- isExpired → bool
-
Checks if the cached preview has expired
no setter
- metadata → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ttl → Duration
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited