PreviewCache class
Cache for formatted preview content
Constructors
- PreviewCache({int maxCacheSize = 100})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxCacheSize → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
Gets the current cache size
no setter
Methods
-
clear(
) → void - Clears all cached previews
-
get(
String messageId) → CachedPreview? - Gets a cached preview by message ID
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
put(
String messageId, CachedPreview preview) → void - Puts a preview in the cache
-
remove(
String messageId) → void - Removes a specific entry from the cache
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited