chat_ui/src/extensions/extension library
Classes
- CollaborativeDocumentConfiguration
-
CollaborativeDocumentConfiguration is a data class that has configuration properties
to customize the functionality and appearance of
CollaborativeDocumentExtension - CollaborativeDocumentOptionStyle
-
CollaborativeDocumentOptionStyle is a data class that has styling-related properties
to customize the appearance of the option in the attachment options menu for the
CollaborativeDocumentExtension - CollaborativeWhiteBoardConfiguration
-
CollaborativeWhiteBoardConfiguration is a data class that has configuration properties
to customize the functionality and appearance of
CollaborativeWhiteBoardExtension - CollaborativeWhiteboardOptionStyle
-
CollaborativeWhiteboardOptionStyle is a data class that has styling-related properties
to customize the appearance of the option in the attachment options menu for the
CollaborativeWhiteBoardExtension - CometChatCollaborativeBubble
-
CometChatCollaborativeDocumentBubblea widget that provides access to collaborative document where users can work on common document - CometChatCollaborativeWebView
- CometChatCollaborativeWebView is widget that renders a WebView
- CometChatCreatePoll
- CometChatCreatePoll is a widget used to create a poll bubble
- CometChatLinkPreviewBubble
-
CometChatLinkPreviewBubble is a widget that is rendered as the content view for
LinkPreviewExtension - CometChatPollsBubble
-
CometChatPollsBubble is a widget that is rendered as the content view for
PollsExtension - CometChatStickerBubble
-
CometChatStickerBubble is a widget that is rendered as the content view for
StickersExtension - CometChatStickerKeyboard
- CometChatStickerKeyboard renders a keyboard consisting of stickers provided by the extension
- ExtensionConstants
- ExtensionConstants is a data class for storing String constants related to extension names
- ExtensionModerator
- ExtensionModerator is an utility class that scans for information of applied extensions inside the metadata of a BaseMessage
- ExtensionUrls
- ExtensionUrls is a data class for storing String constants related to extension urls
- ImageModerationConfiguration
-
ImageModerationConfiguration is a data class that has configuration properties
to customize the functionality and appearance of
ImageModerationExtensioncan be used by a component whereImageModerationExtensionis a child component - ImageModerationFilter
- ImageModerationFilter is a widget that renders an overlay filter over an image with graphic content
- ImageModerationFilterStyle
- ImageModerationFilterStyle is a data class that has styling-related properties to customize the appearance of ImageModerationFilter
- LinkPreviewConfiguration
-
LinkPreviewConfiguration is a data class that has configuration properties
to customize the functionality and appearance of
LinkPreviewExtension - MessageTranslationBubble
-
MessageTranslationBubble is a widget that is rendered as the content view for
MessageTranslationExtension - MessageTranslationConfiguration
-
MessageTranslationConfiguration is a data class that has configuration properties
to customize the functionality and appearance of
MessageTranslationExtension - MessageTranslationOptionStyle
- MessageTranslationOptionStyle is a data class that has styling-related properties to customize the appearance of the option that appears in the bottom modal sheet on long-pressing a message bubble
- PollOptions
- PollsConfiguration
-
PollsConfiguration is a data class that has configuration properties
to customize the functionality and appearance of
PollsExtension - PollsOptionStyle
-
PollsOptionStyle is a data class that has styling-related properties
to customize the appearance of the option in the attachment options menu for the
PollsExtension - Sticker
- Sticker is the model data class for storing the fetched stickers
- StickerAuxiliaryButton
-
StickerAuxiliaryButton is the widget that represents the
StickersExtensionin the auxiliary button view of the CometChatMessageComposer. - StickerConfiguration
-
StickerConfiguration is a data class that has configuration properties
to customize the functionality and appearance of
StickersExtension - ThumbnailGenerationConfiguration
-
ThumbnailGenerationConfiguration is a data class that has configuration properties
to customize the functionality and appearance of
ThumbnailGenerationExtension
Enums
Functions
-
showCometChatCreatePoll(
{required dynamic context, required CometChatColorPalette colorPalette, required CometChatSpacing spacing, String? uid, String? guid, String? title, BaseMessage? quotedMessage, Group? groupObject, User? userObject}) → Future< String?> - showCometChatCreatePoll is a function used to show the create poll widget