chat_ui/src/extensions/polls/cometchat_create_poll library
Classes
- CometChatCreatePoll
- CometChatCreatePoll is a widget used to create a poll bubble
Functions
-
showCometChatCreatePoll(
{required dynamic context, required CometChatColorPalette colorPalette, required CometChatSpacing spacing, String? uid, String? guid, String? title, BaseMessage? quotedMessage, Group? groupObject, User? userObject}) → Future< String?> - showCometChatCreatePoll is a function used to show the create poll widget