StickerAuxiliaryButton class
StickerAuxiliaryButton is the widget that represents the StickersExtension
in the auxiliary button view of the CometChatMessageComposer.
Always shows the sticker icon. When the sticker panel is open the icon is tinted with the primary (purple) colour; otherwise it uses the secondary tint. Tapping toggles the sticker panel open/closed.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- StickerAuxiliaryButton
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardButtonIcon → Widget?
-
keyboardButtonIcon kept for API compatibility (unused)
final
- keyboardIconTint → Color?
-
keyboardIconTint colour override for the active state
final
- onKeyboardTap → dynamic Function()?
-
onKeyboardTap called when the button is tapped while the panel is open
final
- onStickerTap → dynamic Function()?
-
onStickerTap called when the button is tapped while the panel is closed
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stickerButtonIcon → Widget?
-
stickerButtonIcon custom icon widget for the sticker button
final
- stickerIconTint → Color?
-
stickerIconTint colour override for the inactive state
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< StickerAuxiliaryButton> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited