GroupsLoaded class
Loaded state with group data
Contains the list of groups along with pagination and selection state. Implements copyWith for immutable state updates (Requirement 1.4).
- Inheritance
-
- Object
- GroupsState
- GroupsLoaded
Constructors
Properties
-
groups
→ List<
Group> -
Groups list
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMore → bool
-
Whether more groups are available for pagination
final
- isLoadingMore → bool
-
Flag indicating if pagination is in progress (Requirement 10.5)
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchKeyword → String?
-
Current search keyword for filtering
final
-
selectedGroups
→ Set<
String> -
Set of selected group GUIDs (Requirement 8.1)
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
copyWith(
{List< Group> ? groups, bool? hasMore, bool? isLoadingMore, Set<String> ? selectedGroups, String? searchKeyword}) → GroupsLoaded - Create a copy of this state with updated fields (Requirement 1.4)
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited