groupsBloc property
groupsBloc Optional external GroupsBloc instance. If provided, this bloc will be used instead of creating a new one internally. This allows for custom bloc implementations with overridden hooks. Requirement: 9.2
Implementation
final GroupsBloc? groupsBloc;