CometChatMessagePreviewStyle class
- Inheritance
-
- Object
- ThemeExtension<
CometChatMessagePreviewStyle> - CometChatMessagePreviewStyle
- Annotations
Constructors
- CometChatMessagePreviewStyle({Color? messagePreviewBackground, BoxBorder? messagePreviewBorder, BorderRadius? messagePreviewBorderRadius, TextStyle? messagePreviewTitleStyle, Color? messagePreviewTitleColor, TextStyle? messagePreviewSubtitleStyle, Color? messagePreviewSubtitleColor, Color? closeIconColor, Color? replyMessagePreviewCloseIconColor})
-
const
Properties
- closeIconColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- messagePreviewBackground → Color?
-
final
- messagePreviewBorder → BoxBorder?
-
final
- messagePreviewBorderRadius → BorderRadius?
-
final
- messagePreviewSubtitleColor → Color?
-
final
- messagePreviewSubtitleStyle → TextStyle?
-
final
- messagePreviewTitleColor → Color?
-
final
- messagePreviewTitleStyle → TextStyle?
-
final
- replyMessagePreviewCloseIconColor → Color?
-
Color for the media type icon shown next to the subtitle for non-text messages
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
{Color? messagePreviewBackground, BoxBorder? messagePreviewBorder, BorderRadius? messagePreviewBorderRadius, TextStyle? messagePreviewTitleStyle, Color? messagePreviewTitleColor, TextStyle? messagePreviewSubtitleStyle, Color? messagePreviewSubtitleColor, Color? closeIconColor, Color? replyMessagePreviewCloseIconColor}) → CometChatMessagePreviewStyle -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< CometChatMessagePreviewStyle> ? other, double t) → CometChatMessagePreviewStyle -
Linearly interpolate with another ThemeExtension object.
override
-
merge(
CometChatMessagePreviewStyle? other) → CometChatMessagePreviewStyle -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
BuildContext context) → CometChatMessagePreviewStyle