chat_ui/src/notification_feed/utils/timestamp_grouper library
Classes
- TimestampGroup
- Represents a group of feed items sharing the same calendar day.
Functions
-
getRelativeTime(
int sentAtSeconds, String locale) → String - Get a relative time string for a single item matching CometChatDate.setDayTime:
-
groupByTimestamp(
List< NotificationFeedItem> items, String locale) → List<TimestampGroup> -
Groups notification feed items by their
sentAttimestamp into sections.