TimestampGroup class
Represents a group of feed items sharing the same calendar day.
Constructors
-
TimestampGroup({required String label, required List<
NotificationFeedItem> items}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
NotificationFeedItem> -
Feed items within this group, sorted newest-first.
final
- label → String
-
Display label for the group header (e.g., "Today", "Yesterday", "Mon, Jan 15").
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited