ThreadedHeaderServiceLocator class
Service Locator for Threaded Header module. Singleton — call setup once during app startup.
Properties
- getAllMessageTemplatesUseCase → GetAllMessageTemplatesUseCase
-
no setter
- getMessageTemplateUseCase → GetMessageTemplateUseCase
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInitialized → bool
-
no setter
- repository → ThreadedHeaderRepository
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → Future< void> -
setup(
{ThreadedHeaderDataSource? dataSource}) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → ThreadedHeaderServiceLocator
-
no setter