AIAssistantCardEndedEvent class
Represents an AI Assistant card_end streaming event.
Delivered when the AI agent has finished the card generation flow. The UI can hide any loading indicator keyed by cardId.
Extends AIAssistantBaseEvent and is delivered through the existing
onAIAssistantEventReceived listener.
- Inheritance
-
- Object
- AIAssistantBaseEvent
- AIAssistantCardEndedEvent
Constructors
-
AIAssistantCardEndedEvent({String? streamMessageId, int? runId, String? threadId, String? cardId, int? id, String? type, String? conversationId, String? parentId, Map<
String, dynamic> ? additionalProperties}) -
AIAssistantCardEndedEvent.fromMap(Map<
String, dynamic> map) -
Creates an instance from a map.
factory
Properties
-
additionalProperties
↔ Map<
String, dynamic> ? -
getter/setter pairinherited
- cardId ↔ String?
-
getter/setter pair
- conversationId ↔ String?
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int?
-
getter/setter pairinherited
- parentId ↔ String?
-
getter/setter pairinherited
- runId ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streamMessageId ↔ String?
-
getter/setter pair
- threadId ↔ String?
-
getter/setter pair
- type ↔ String?
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the object to a map.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited