CometChatCardCodeBlockElement class final
A code block element with optional language label and syntax styling.
- Inheritance
-
- Object
- CometChatCardElement
- CometChatCardCodeBlockElement
Constructors
- CometChatCardCodeBlockElement({required String id, required String content, String? language, dynamic backgroundColor, dynamic textColor, dynamic padding, double? borderRadius, double? fontSize, double? languageLabelFontSize, dynamic languageLabelColor})
-
const
-
CometChatCardCodeBlockElement.fromJson(Map<
String, dynamic> json) -
factory
Properties
- backgroundColor → dynamic
-
final
- borderRadius → double?
-
final
- content → String
-
final
- fontSize → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
finalinherited
- language → String?
-
final
- languageLabelColor → dynamic
-
final
- languageLabelFontSize → double?
-
final
- padding → dynamic
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textColor → dynamic
-
final
- type → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited