CometChatCardImageElement class final
An image element that renders a network image with optional sizing and fit.
The url can be a plain string or a CometChatCardColorValue for theme-aware image URLs (different images for light/dark mode).
- Inheritance
-
- Object
- CometChatCardElement
- CometChatCardImageElement
Constructors
- CometChatCardImageElement({required String id, required dynamic url, String? altText, String? fit, dynamic width, dynamic height, double? borderRadius, dynamic padding})
-
const
-
CometChatCardImageElement.fromJson(Map<
String, dynamic> json) -
factory
Properties
- altText → String?
-
final
- borderRadius → double?
-
final
- fit → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → dynamic
-
final
- id → String
-
finalinherited
- padding → dynamic
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
finalinherited
- url → dynamic
-
final
- width → dynamic
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited