shared_ui/src/clean_architecture/clean_architecture
library
Classes
-
Action
-
This class represents an action performed in the chat.
-
ActionElementFields
-
-
ActionElementUtils
-
-
ActionEntity
-
A base class for representing actions in a chat application.
-
ActionItem
-
ActionItem is the type of items displayed in CometChatAttachmentOptionSheet
-
ActionMessageTypeConstants
-
-
ActionTypeConstants
-
-
AdditionalConfigurations
-
AdditionalConfigurations is a class that can be used to add additional configurations to the UI Kit
-
AgenticKeys
-
-
AIAssistantBaseEvent
-
-
AIAssistantContentReceivedEvent
-
-
AIAssistantMessage
-
Represents an AI Assistant message within the chat.
-
AIAssistantMessageEndedEvent
-
Represents an event when an AI Assistant message has ended.
-
AIAssistantRunFinishedEvent
-
Represents an event when an AI Assistant run has finished.
-
AIAssistantRunStartedEvent
-
Represents an event when an AI Assistant run has started.
-
AIAssistantToolArgumentEvent
-
Represents an AI Assistant tool argument event.
-
AIAssistantToolEndedEvent
-
Represents an AI Assistant tool ended event.
-
AIAssistantToolResultEvent
-
Represents an AI Assistant tool result event.
-
AIAssistantToolStartedEvent
-
Represents an AI Assistant tool started event.
-
AIToolArgumentMessage
-
Represents a tool argument message in AI Assistant.
-
AIToolCall
-
Represents a tool call used in AI Assistant messages.
-
AIToolCallFunction
-
Represents a function call associated with an AI tool call.
-
AIToolResultMessage
-
Represents a tool result message in AI Assistant.
-
AIUtils
-
-
APIAction
-
Represents an action that makes an API request in a chat application.
-
APIRequestTypeConstants
-
-
AppEntity
-
Represents an entity within the application.
-
AppSettings
-
Represents application settings.
-
AppSettingsBuilder
-
Builder class for
AppSettings.
-
AssetConstants
-
AssetConstants is a utility class that stores String constants of asset image paths
-
Attachment
-
Represents a file attachment.
-
AttributedText
-
AttributedText is a class which is used to style the text
-
AudioBubbleConstants
-
-
AudioBubbleEvents
-
-
AudioBubbleFactory
-
Factory for creating audio message bubbles.
-
AudioBubbleStream
-
AudioBubbleStream a singleton class to handle the audio bubble events stream
-
AudioServiceLocator
-
Service Locator for Audio Bubble use cases
Provides convenient access to audio-related use cases
Wires to SharedUiServiceLocator for dependency resolution
-
AudioStateEntity
-
-
AudioStateManager
-
Global state manager for audio bubbles to preserve playback state across widget rebuilds
-
AudioStateRepository
-
Abstract repository for Audio State management
-
AudioStateUpdateEntity
-
Event emitted when audio state changes
-
BannedGroupMembersRequest
-
A request object for fetching banned group members.
-
BannedGroupMembersRequestBuilder
-
Builder class for
BannedGroupMembersRequest.
-
BaseInputElement<T>
-
-
BaseInteractiveElement
-
-
BaseMessage
-
Represents a basic chat message.
-
BaseStyles
-
BaseStyles is the base style class for most style classes provided by CometChatUIKit
-
BlockedUsersRequest
-
A request object for fetching blocked users.
-
BlockedUsersRequestBuilder
-
Builder class for
BlockedUsersRequest.
-
BubbleFactory<T extends BaseMessage>
-
Abstract factory for creating message bubble content widgets.
-
BubbleUtils
-
-
ButtonElement
-
Represents a button model class , used to draw button element .
-
ButtonElementStyle
-
-
Call
-
Represents a call event within the chat.
-
CallStatusConstants
-
CallStatusConstants is a utility class that stores String constants of various stages of Call
-
CallTypeConstants
-
-
CardBubbleStyle
-
CardBubbleStyle is a model class for card widget. It contains the styles for the card widget.
-
CardMessage
-
Represents a message with a card view that contains interactive elements.
-
CardMessageKeys
-
-
CCExtension
-
Represents a CometChat extension.
-
CheckBoxElement
-
Represents a checkbox model class , used to draw checkbox .
-
CheckBoxElementStyle
-
-
CircularIntervalList<T>
-
-
CometChat
-
Flutter wrapper for using CometChat SDK.
-
CometChatAudioBubble
-
CometChatAudioBubble creates a widget that gives audio bubble
-
CometChatAudioBubbleStyle
-
CometChatAudioBubbleStyle is a data class that has styling-related properties
to customize the appearance of CometChatAudioBubble
-
CometChatAudioBubbleV2
-
Rewritten CometChatAudioBubble with lazy loading and gesture-controlled waveform
-
CometChatBaseOptions
-
CometChatBaseOptions is a model class which contains a set of properties that is be used by CometChatDetailsOption, CometChatGroupMemberOption thus forming a common base class for both
-
CometChatBlockedUsersDirection
-
-
CometChatCallBubbleStyle
-
CometChatCallBubbleStyle is a data class that has styling-related properties
to customize the appearance of CometChatCallBubble
-
CometChatCallButtonsStyle
-
CometChatCallButtonsStyle is the data class that contains style configuration for CometChatCallButtons
-
CometChatCallStatus
-
-
CometChatCallType
-
-
CometChatCardBubble
-
CometChatCardBubble creates the card view for InteractiveMessage with type MessageTypeConstants.card by default
-
CometChatCollaborativeBubbleStyle
-
CometChatCollaborativeBubbleStyle is a data class that has styling-related properties
to customize the appearance of CometChatCollaborativeBubble
-
CometChatColorHelper
-
The CometChatColorHelper class provides methods to blend two colors together and generate a color palette based on the base color and blend color provided.
-
CometChatColorPalette
-
The CometChatColorPalette class provides a color palette for the CometChat UI Kit.
-
CometChatConversationType
-
-
CometChatDetailsOption
-
CometChatDetailsOption is a model class which contains information about options available for every CometChatDetailsTemplate
-
CometChatDetailsTemplate
-
CometChatDetailsTemplate is the section of options displayed in
CometChatDetails
-
CometChatEmailFormatter
-
CometChatEmailFormatter is a class which is used to style the email text
-
CometChatFileBubble
-
CometChatFileBubble creates a widget that gives file bubble
-
CometChatFileBubbleStyle
-
CometChatFileBubbleStyle is a data class that has styling-related properties
to customize the appearance of CometChatFileBubble
-
CometChatGroupMemberOption
-
CometChatGroupMemberOption is a model class which contains information about options available to execute for every GroupMember
-
CometChatGroupType
-
-
CometChatHelper
-
-
CometChatImageBubble
-
CometChatImageBubble creates a widget that gives image bubble
-
CometChatImageBubbleStyle
-
CometChatImageBubbleStyle is a data class that has styling-related properties
to customize the appearance of CometChatImageBubble
-
CometChatIncomingMessageBubbleStyle
-
CometChatIncomingMessageBubbleStyle is a data class that has styling-related properties
to customize the appearance of the incoming message bubble
-
CometChatListBase
-
CometChatListBase is a top level container widget
used internally by components like CometChatUsers, CometChatGroups, CometChatConversations, CometChatGroupMembers
-
CometChatMarquee
-
-
CometChatMediaRecorder
-
CometChatMediaRecorder is a class that allows users to record audio messages.
It has a start button to start recording, a stop button to stop recording, a play button to play the recorded message, a pause button to pause the recorded message, a submit button to submit the recorded message and a close button to close the media recorder.
-
CometChatMediaRecorderStyle
-
CometChatMediaRecorderStyle is a model class for customizing the styles of CometChatMediaRecorder widget.
-
CometChatMemberScope
-
-
CometChatMentionsFormatter
-
CometChatMentionsFormatter is a class which is used to format the mentions
It extends the CometChatTextFormatter
It has properties like composerId, onError, suggestionListEventSink, previousTextEventSink, message, mentionedUsersMap, mentionCount, mentionStartIndex, mentionEndIndex, lastCursorPos
It has methods like handlePreMessageSend, initializeFetchRequest, fetchItems, onMessageEdit, resetMentionsTracker, cursorInMentionTracker, onChange, onScrollToBottom
It has a constructor which takes trackingCharacter, pattern,
disableSuggestions, showLoadingIndicator, onSearch, group, composerId, onError, suggestionListEventSink, previousTextEventSink, theme, message, messageBubbleTextStyle, groupMembersRequestBuilder, usersRequestBuilder, messageInputTextStyle as a parameter
It has a method onMentionTap which is used to handle the mention tap
-
CometChatMentionsStyle
-
CometChatMentionsStyle is a data class that has styling-related properties
to customize the appearance of mentions in the message
-
CometChatMessageBubbleStyleData
-
CometChatMessageBubbleStyleData is a model class which contains the style properties for the message bubble.
-
CometChatMessageCategory
-
-
CometChatMessageComposerAction
-
CometChatMessageComposerAction is the type of menu items allowed to be displayed
CometChatMessageComposer
-
CometChatMessageEvents
-
Event emitting class for
CometChatMessages
-
CometChatMessageInput
-
CometChatMessageInput is a component that provides a skeleton layout for contents of CometChatMessageComposer like TextField, auxiliary options, primary button view and attachment options.
-
CometChatMessageInputStyle
-
CometChatMessageInputStyle is a data class that has styling-related properties
to customize the appearance of CometChatMessageInput
-
CometChatMessageOption
-
Model class for message options
-
CometChatMessageTemplate
-
CometChatMessageTemplate class for setting message types and rendering appropriate views in the message list
-
CometChatMessageType
-
-
CometChatNotificationErrorCode
-
-
CometChatNotificationErrorMessages
-
-
CometChatNotifications
-
Provides notification management functionality for CometChat.
-
CometChatOption
-
CometChatOption is a model class which is used to execute any action on a CometChatListItem
-
CometChatOutgoingMessageBubbleStyle
-
CometChatOutgoingMessageBubbleStyle is a data class that has styling-related properties
to customize the appearance of the outgoing message bubble
-
CometChatPhoneNumberFormatter
-
CometChatPhoneNumberFormatter is a class which is used to style the phone number text
-
CometChatPollsBubbleStyle
-
PollsBubbleStyle is a data class that has styling-related properties
to customize the appearance of CometChatPollsBubble
-
CometChatReactionList
-
CometChatReactionList is a StatefulWidget that displays the list of reactions
for a particular message. It requires reactionRequestBuilder to fetch the
reactions of a particular message. It also requires message to fetch
the reactions of a particular message. It also requires onTap to perform
some action on click of a particular reaction.
-
CometChatReactionListStyle
-
CometChatReactionListStyle is a class which is used to set the style for the reaction list
It takes
loadingStateColor, emptyTextStyle, errorTextStyle, subtitleTextStyle, width, height, background, gradient, border, borderRadius as a parameter
-
CometChatReactions
-
CometChatReactions is a widget which is used to set the reactions
It takes reactionList, theme, alignment, onReactionTap, onReactionLongPress, style as a parameter
-
CometChatReactionsStyle
-
CometChatReactionsStyle is a class which is used to set the style for the reactions
It takes emojiTextStyle, countTextStyle,
width, height, background, gradient, border, borderRadius as a parameter
-
CometChatReceiptType
-
-
CometChatReceiverType
-
-
CometChatShimmerEffect
-
-
CometChatSpacing
-
CometChatSpacing is a class that holds the spacing values for the CometChat UI Kit.
-
CometChatStartConversationType
-
CometChatStartConversationType is a utility class that stores String constants of the types of
CometChatContacts
-
CometChatStickerBubbleStyle
-
CometChatStickerBubbleStyle is a data class that has styling-related properties fo CometChatStickerBubble
-
CometChatSubscriptionType
-
-
CometChatTextBubble
-
CometChatTextBubble is a widget that gives text bubble
-
CometChatTextBubbleStyle
-
CometChatTextBubbleStyle is a data class that has styling-related properties
to customize the appearance of CometChatTextBubble
-
CometChatTextFormatter
-
CometChatTextFormatter is an abstract class which is used to format the text
It has properties like trackingCharacter, pattern, onSearch, showLoadingIndicator, messageBubbleTextStyle, messageInputTextStyle
It has methods like init, handlePreMessageSend, onScrollToBottom, buildInputFieldText, mergeAttributedText, getAttributedText, onChange, getLoadingIndicator, getMessageInputTextStyle, getMessageBubbleTextStyle
-
CometChatTextStyleBody
-
CometChatTextStyleBody is a class that gives the styling to the text displayed in the body
-
CometChatTextStyleButton
-
CometChatTextStyleButton is a class that gives the styling to the text displayed in the buttons
-
CometChatTextStyleCaption1
-
CometChatTextStyleCaption1 is a class that gives the styling to the text displayed in the caption
-
CometChatTextStyleCaption2
-
CometChatTextStyleCaption2 is a class that gives the styling to the text displayed in the caption2
-
CometChatTextStyleHeading1
-
CometChatTextStyleHeading1 is a class that gives the styling to the text displayed in the heading1
-
CometChatTextStyleHeading2
-
CometChatTextStyleHeading2 is a class that gives the styling to the text displayed in the heading3
-
CometChatTextStyleHeading3
-
CometChatTextStyleHeading3 is a class that gives the styling to the text displayed in the heading3
-
CometChatTextStyleHeading4
-
CometChatTextStyleHeading4 is a class that gives the styling to the text displayed in the CometChatApp.
-
CometChatTextStyleLink
-
CometChatTextStyleLink is a class that gives the styling to the text displayed in the link
-
CometChatTextStyleTitle
-
CometChatTextStyleTitle is a class that gives the styling to the text displayed in the title
-
CometChatTheme
-
-
CometChatThemeHelper
-
CometChatThemeHelper is a class that gives the styling to the text displayed in the buttons
-
CometChatThemeMode
-
-
CometChatTypography
-
-
CometChatUIEvents
-
-
CometChatUIKit
-
-
CometChatUrlFormatter
-
CometChatUrlFormatter is a class which is used to style the url text
-
CometChatUserEvents
-
-
CometChatUserStatus
-
-
CometChatVideoBubble
-
CometChatVideoBubble creates a widget that gives video bubble
-
CometChatVideoBubbleStyle
-
CometChatVideoBubbleStyle is a data class that has styling-related properties
to customize the appearance of CometChatVideoBubble
-
CometChatWSState
-
-
Conversation
-
Represents a chat conversation.
-
ConversationOptionConstants
-
ConversationOptionConstants is a utility class that stores String constants of options available for Conversation items
-
ConversationsRequest
-
A request object for fetching conversations.
-
ConversationsRequestBuilder
-
Builder class for
ConversationsRequest.
-
ConversationType
-
-
ConversationUpdateSettings
-
-
ConversationUtils
-
ConversationUtils is an Utility class that helps to
the last message for any conversation and also
provides the default action to execute on a conversation
-
CurrentUser
-
Represents the currently authenticated user.
-
CustomAction
-
Represents a custom action in a chat application.
-
CustomInteractiveMessage
-
Represents a message that includes various types of messages for interactive elements.
-
CustomMessage
-
Represents a custom chat message.
-
-
CustomStateView
-
-
DashOffset
-
-
DateTimeElement
-
Represents a dropdown model class , used to draw dropdown .
-
DateTimeElementStyle
-
-
DateTimeFormatterCallback
-
-
DaySchedule
-
-
Debouncer
-
-
DefaultBubbleFactories
-
Utility class providing default bubble factories for all message types.
-
DeletedBubbleFactory
-
Factory for creating deleted message bubbles.
-
DeleteMessageUseCase
-
Delete message use case
Handles message deletion with validation
-
DetailsTemplateConstants
-
DetailsTemplateConstants is a utility class that stores String constants of the types of CometChatDetailsTemplate
-
DetailUtils
-
DetailUtils is a Utility class that provides
the default options and templates available in
CometChatDetails
which allows users to block and unblock other users
group members to view, add, ban other members
-
DottedBorder
-
-
DropdownElement
-
Represents a dropdown model class , used to draw dropdown .
-
DropDownElementStyle
-
-
ElementEntity
-
-
EmojiUtils
-
Utility for detecting emoji-only messages and determining display sizes.
-
ErrorCode
-
-
ErrorConstants
-
-
ErrorMessage
-
-
EventHandler
-
-
ExtensionType
-
-
Failure
-
Failure state that can be returned from any Result
-
FileBubbleFactory
-
Factory for creating file message bubbles.
-
FileConstants
-
-
FileSizeCheckUtil
-
-
FileUtils
-
-
FlagDetail
-
-
FlagReason
-
-
Formatter
-
-
FormatterUtils
-
FormatterUtils is an utility class which is used to style the text in the message bubble and the conversation subtitle
-
FormMessage
-
Represents a message that includes a form with interactive elements.
-
GetAudioStateStreamUseCase
-
Use case to get audio state stream
-
GetAudioStateUseCase
-
Use case to get audio state
-
-
GetMessagesParams
-
-
GetMessagesUseCase
-
Get messages use case
Retrieves messages from a conversation with caching and filtering
-
GetPlayStateUseCase
-
Use case to get current play state
-
GetUnreadCountUseCase
-
Get unread count use case
-
Group
-
Represents a group within the chat.
-
GroupDataSource
-
Abstract data source for group operations
-
GroupDataSourceImpl
-
CometChat SDK implementation of GroupDataSource
-
GroupEntity
-
Domain entity representing a chat group
Pure Dart model with no dependencies on CometChat SDK
-
GroupMapper
-
Mapper to convert CometChat SDK Group to GroupEntity
-
GroupMember
-
Represents a group member within the chat.
-
GroupMemberOptionConstants
-
GroupMemberOptionConstants is a utility class that stores String constants of the actions permitted to a GroupMember to execute on a particular Group
-
GroupMemberScope
-
GroupMemberScope is a utility class that stores String constants of scope of GroupMember with respect to a particular Group
-
GroupMembersRequest
-
A request object for fetching group members.
-
GroupMembersRequestBuilder
-
Builder class for
GroupMembersRequest.
-
GroupOptionConstants
-
GroupOptionConstants is a utility class that stores String constants of the options available in
CometChatDetails if it is being rendered for a Group
-
GroupPreferences
-
-
GroupRepository
-
Abstract repository for group operations
-
GroupRepositoryImpl
-
Implementation of GroupRepository using SDK data source
-
GroupsRequest
-
A request object for fetching groups.
-
GroupsRequestBuilder
-
Builder class for
GroupsRequest.
-
GroupTypeConstants
-
GroupTypeConstants is a utility class that stores String constants of the types of Group
-
IDMapConstants
-
-
ImageBubbleFactory
-
Factory for creating image message bubbles.
-
Interaction
-
Represents an interaction within the chat.
-
InteractionGoal
-
Represents an interaction goal within the chat.
-
InteractionGoalType
-
-
InteractionGoalTypeConstants
-
-
InteractionReceipt
-
Represents an interaction receipt within the chat.
-
InteractiveMessage
-
Represents a interactive message within the chat.
-
InteractiveMessageConstants
-
-
InteractiveMessageUtils
-
-
LabelElement
-
Represents a label model class , used to draw label .
-
ListBaseStyle
-
ListBaseStyle is a data class that has styling-related properties
to customize the appearance of CometChatListBase
-
LiveReactionConstants
-
LiveReactionConstants is a utility class that stores constant values related to functioning of TransientMessage
-
LoggerConfig
-
Immutable configuration for SDK logging.
-
MarkMessagesAsReadUseCase
-
Mark messages as read use case
-
MediaMessage
-
Represents a media message within the chat.
-
MediaPicker
-
-
MessageCategoryConstants
-
MessageCategoryConstants is a utility class that stores String constants of categories of messages
-
MessageComposerSuggestions
-
-
MessageDataSource
-
Abstract data source for message operations
Wraps CometChat SDK calls with error handling
-
MessageDataSourceImpl
-
CometChat SDK implementation of MessageDataSource
-
MessageEntity
-
Domain entity representing a chat message
Pure Dart model with no dependencies on CometChat SDK
-
MessageListEmpty
-
Empty state - no messages found
-
MessageListError
-
Error state - operation failed
-
MessageListInitial
-
Initial state - before any operation
-
MessageListLoading
-
Loading state - while fetching data
-
MessageListLoadingMore
-
Pagination state - loading more messages
-
MessageListMessageDeleted
-
Message deleted state
-
MessageListMessageSent
-
Message sent state
-
MessageListSearching
-
Search state - searching for messages
-
MessageListSearchResults
-
Search results state
-
MessageListSending
-
Message sending state
-
MessageListState
-
Base state class for all message list states
-
MessageListSuccess
-
Success state - data loaded successfully
-
MessageMapper
-
Mapper to convert CometChat SDK BaseMessage to MessageEntity
-
MessageOptionConstants
-
MessageOptionConstants is a utility class that stores String constants of the actions permitted to execute on a particular BaseMessage
-
MessageReceipt
-
Represents a message receipt within the chat.
-
MessageReceiptUtils
-
MessageReceiptUtils is a utility class to determine receipt status
-
MessageRepository
-
Abstract repository for message operations
Defines contract for message-related use cases
-
MessageRepositoryImpl
-
Implementation of MessageRepository using SDK data source
-
MessagesRequest
-
A request object for fetching messages.
-
MessagesRequestBuilder
-
Allows step-by-step creation of an
MessagesRequest object.
-
MessageTypeConstants
-
MessageTypeConstants is a utility class that stores String constants of types of messages
-
MessageUtils
-
A utility class for message related operations.
This class contains methods required for message related operations.
It is used to get the message bubble, message time, and message receipt icon.
-
MetadataConstants
-
MetadataConstants is a utility class that stores String constants to use in the
metadata property of a BaseMessage
-
ModelFieldConstants
-
-
ModerationCheckUtil
-
-
MutedConversation
-
-
MutePreferences
-
-
NotificationCategoriesRequest
-
A request object for fetching notification categories.
-
NotificationCategoriesRequestBuilder
-
Builder class for
NotificationCategoriesRequest.
-
NotificationCategory
-
Represents a notification category used for filtering notification feed items.
-
NotificationFeedItem
-
Represents a notification feed item within the CometChat notification feed.
-
NotificationFeedRequest
-
A request object for fetching notification feed items.
-
NotificationFeedRequestBuilder
-
Builder class for
NotificationFeedRequest.
-
NotificationPreferences
-
-
OneOnOnePreferences
-
-
OptionElement
-
-
PauseAllExceptUseCase
-
Use case to pause all except specified
-
PauseAudioUseCase
-
Use case to pause audio
-
PickedFile
-
-
PlayAudioUseCase
-
Use case to play audio
-
PushNotification
-
Represents a push notification payload for engagement tracking.
-
RadioButtonElement
-
Represents a radio button model class , used to draw radio button .
-
RadioButtonElementStyle
-
-
Reaction
-
Represents a reaction within the chat.
-
ReactionAction
-
-
ReactionConstants
-
-
ReactionCount
-
Represents a count of reactions within the chat.
-
ReactionEvent
-
-
ReactionsRequest
-
A request object for fetching reactions.
-
ReactionsRequestBuilder
-
Builder class for
ReactionsRequest.
-
ReceiptTypeConstants
-
ReceiptTypeConstants is a utility class that stores String constants of the various stages of message delivery
-
ReceiverTypeConstants
-
ReceiverTypeConstants is a utility class that stores String constants of the types of AppEntity that can receive a BaseMessage
-
RegexConstants
-
RegexConstants is a utility contains patterns or verifying selective text inputs
-
RemoveAudioStateUseCase
-
Use case to remove audio state
-
RequestBuilderConstants
-
-
Result<T>
-
Generic Result wrapper for handling success and failure states
Following the Either pattern for functional error handling
-
SchedulerConstants
-
-
SchedulerMessage
-
-
SchedulerUtils
-
-
SDKMethods
-
-
SearchMessagesParams
-
-
SearchMessagesUseCase
-
Search messages use case
Searches messages with query validation
-
SectionSeparator
-
-
SeekAudioUseCase
-
Use case to seek audio
-
SendMessageParams
-
-
SendMessageUseCase
-
Send message use case
Handles message sending with validation and error handling
-
SetSourceConstant
-
-
SharedUiServiceLocator
-
Service Locator for clean architecture dependency injection
-
SingleSelectElement
-
Represents a single select element model class used to create a single select input element.
-
SnackBarConfiguration
-
-
SnackBarUtils
-
-
StatusIndicatorUtils
-
-
StopAllAudioUseCase
-
Use case to stop all audio
-
StopAudioUseCase
-
Use case to stop audio
-
StreamEntity
-
Stream Entity - Domain Model
Represents a stream in the domain layer
Pure data class with no external dependencies
-
StreamStatusUpdate
-
Detailed stream status update entity
-
Success<T>
-
Success state containing the data
-
SuggestionListItem
-
SuggestionListItem is a modal class used to define the structure of the list item
used in the suggestions list.
-
SvgAssetConstants
-
SvgAssetConstants is a utility class that stores String constants of asset image paths
-
TextBubbleFactory
-
Factory for creating text message bubbles.
-
TextInputElement
-
Represents a text input model class , used to draw text input element .
-
TextInputElementStyle
-
-
TextInputPlaceholder
-
placeholder model for Text field
-
TextMessage
-
Represents a text message within the chat.
-
Utility for extracting thumbnail URLs from a message's metadata,
typically populated by the CometChat
thumbnail-generation extension
for image and video attachments.
-
TimeRange
-
-
TransientMessage
-
Represents a temporary or transient message within the chat.
-
Translations
-
-
TypingIndicator
-
Represents a typing indicator within the chat.
-
UIConstants
-
UIConstants contains properties essential and limited to setting up the ui kit
-
UIElementTypeConstants
-
-
UIEventHandler
-
-
UIEventUtils
-
-
UIStateUtils
-
-
UITabNameConstants
-
UITabNameConstants is a utility class that stores String constants of the names of the tabs available for
CometChatUI
-
UnmutedConversation
-
-
UnreadCountError
-
-
UnreadCountInitial
-
-
UnreadCountLoading
-
-
UnreadCountState
-
State for unread count
-
UnreadCountSuccess
-
-
UpdateSettingsConstant
-
-
URLNavigationAction
-
Represents an action for URL navigation within a chat application.
-
UseCase<Type, Params>
-
Base use case class
All use cases should extend this class
-
User
-
Represents a user within the chat.
-
UserDataSource
-
Abstract data source for user operations
-
UserDataSourceImpl
-
CometChat SDK implementation of UserDataSource
-
UserEntity
-
Domain entity representing a chat user
Pure Dart model with no dependencies on CometChat SDK
-
UserMapper
-
Mapper to convert CometChat SDK User to UserEntity
-
UserOptionConstants
-
UserOptionConstants is a utility class that stores String constants of the options available in
CometChatDetails if it is being rendered for a User
-
UserPresence
-
Represents user presence information from WebSocket events.
-
UserRepository
-
Abstract repository for user operations
-
UserRepositoryImpl
-
Implementation of UserRepository using SDK data source
-
UsersRequest
-
A request object for fetching users.
-
UsersRequestBuilder
-
Builder class for
UsersRequest.
-
UserStatusConstants
-
UserStatusConstants is a utility class that stores String constants of the online/offline status of an User
-
VideoBubbleFactory
-
Factory for creating video message bubbles.
-
WidgetPositionUtil
-
Typedefs
-
AIAssistantToolEventResult
= AIAssistantToolResultEvent
-
Deprecated alias for AIAssistantToolResultEvent.
-
BubbleViewProvider
= Widget? Function(BuildContext context, BaseMessage message, BubbleAlignment alignment)
-
Callback for providing custom views for message bubble slots.
Returns Widget or null to use default/hide.
-
ComposerActionsBuilder
= List<CometChatMessageComposerAction> Function(BuildContext context, User? user, Group? group, Map<String, dynamic>? id)
-
-
ComposerWidgetBuilder
= Widget Function(BuildContext context, User? user, Group? group, Map<String, dynamic>? id)
-
-
OnEmpty
= void Function()
-
OnEmpty defines the structure of empty handler used by the components in the ui kit
-
OnError
= dynamic Function(Exception e)
-
OnError defines the structure of error handler used by the components in the ui kit
-
OnLoad<T>
= dynamic Function(List<T> list)
-
OnLoad defines the structure of loading handler used by the components in the ui kit
-
UserGroupBuilder
= dynamic Function(BuildContext context, User? user, Group? group)
-