shared_ui/src/clean_architecture/data/data library
Classes
- ActionEntity
- A base class for representing actions in a chat application.
- ActionItem
- ActionItem is the type of items displayed in CometChatAttachmentOptionSheet
- AdditionalConfigurations
- AdditionalConfigurations is a class that can be used to add additional configurations to the UI Kit
- APIAction
- Represents an action that makes an API request in a chat application.
-
BaseInputElement<
T> - BaseInteractiveElement
- BaseStyles
- BaseStyles is the base style class for most style classes provided by CometChatUIKit
- ButtonElement
- Represents a button model class , used to draw button element .
- ButtonElementStyle
- CardMessage
- Represents a message with a card view that contains interactive elements.
- CheckBoxElement
- Represents a checkbox model class , used to draw checkbox .
- CheckBoxElementStyle
- CometChatBaseOptions
- CometChatBaseOptions is a model class which contains a set of properties that is be used by CometChatDetailsOption, CometChatGroupMemberOption thus forming a common base class for both
- CometChatCallBubbleStyle
- CometChatCallBubbleStyle is a data class that has styling-related properties to customize the appearance of CometChatCallBubble
- CometChatCallButtonsStyle
- CometChatCallButtonsStyle is the data class that contains style configuration for CometChatCallButtons
- CometChatCollaborativeBubbleStyle
- CometChatCollaborativeBubbleStyle is a data class that has styling-related properties to customize the appearance of CometChatCollaborativeBubble
- CometChatDetailsOption
- CometChatDetailsOption is a model class which contains information about options available for every CometChatDetailsTemplate
- CometChatDetailsTemplate
-
CometChatDetailsTemplate is the section of options displayed in
CometChatDetails - CometChatGroupMemberOption
- CometChatGroupMemberOption is a model class which contains information about options available to execute for every GroupMember
- CometChatIncomingMessageBubbleStyle
- CometChatIncomingMessageBubbleStyle is a data class that has styling-related properties to customize the appearance of the incoming message bubble
- CometChatMessageComposerAction
-
CometChatMessageComposerAction is the type of menu items allowed to be displayed
CometChatMessageComposer - CometChatMessageOption
- Model class for message options
- CometChatMessageTemplate
- CometChatMessageTemplate class for setting message types and rendering appropriate views in the message list
- CometChatOption
- CometChatOption is a model class which is used to execute any action on a CometChatListItem
- CometChatOutgoingMessageBubbleStyle
- CometChatOutgoingMessageBubbleStyle is a data class that has styling-related properties to customize the appearance of the outgoing message bubble
- CometChatPollsBubbleStyle
-
PollsBubbleStyleis a data class that has styling-related properties to customize the appearance of CometChatPollsBubble - CometChatStickerBubbleStyle
- CometChatStickerBubbleStyle is a data class that has styling-related properties fo CometChatStickerBubble
- CustomAction
- Represents a custom action in a chat application.
- CustomInteractiveMessage
- Represents a message that includes various types of messages for interactive elements.
- DateTimeElement
- Represents a dropdown model class , used to draw dropdown .
- DateTimeElementStyle
- DateTimeFormatterCallback
- DropdownElement
- Represents a dropdown model class , used to draw dropdown .
- DropDownElementStyle
- ElementEntity
- FormMessage
- Represents a message that includes a form with interactive elements.
- GroupDataSource
- Abstract data source for group operations
- GroupDataSourceImpl
- CometChat SDK implementation of GroupDataSource
- GroupMapper
- Mapper to convert CometChat SDK Group to GroupEntity
- GroupRepositoryImpl
- Implementation of GroupRepository using SDK data source
- LabelElement
- Represents a label model class , used to draw label .
- MessageDataSource
- Abstract data source for message operations Wraps CometChat SDK calls with error handling
- MessageDataSourceImpl
- CometChat SDK implementation of MessageDataSource
- MessageMapper
- Mapper to convert CometChat SDK BaseMessage to MessageEntity
- MessageRepositoryImpl
- Implementation of MessageRepository using SDK data source
- OptionElement
- RadioButtonElement
- Represents a radio button model class , used to draw radio button .
- RadioButtonElementStyle
- SchedulerMessage
- SingleSelectElement
- Represents a single select element model class used to create a single select input element.
- SnackBarConfiguration
- SuggestionListItem
- SuggestionListItem is a modal class used to define the structure of the list item used in the suggestions list.
- TextInputElement
- Represents a text input model class , used to draw text input element .
- TextInputElementStyle
- TextInputPlaceholder
- placeholder model for Text field
- TimeRange
- Represents an action for URL navigation within a chat application.
- UserDataSource
- Abstract data source for user operations
- UserDataSourceImpl
- CometChat SDK implementation of UserDataSource
- UserMapper
- Mapper to convert CometChat SDK User to UserEntity
- UserRepositoryImpl
- Implementation of UserRepository using SDK data source
Properties
- cometchatConstantString ↔ String
-
getter/setter pair
Functions
-
cast<
T> (dynamic x) → T?