shared_ui/src/clean_architecture/presentation/presentation
library
Classes
-
AttributedText
-
AttributedText is a class which is used to style the text
-
AudioBubbleFactory
-
Factory for creating audio message bubbles.
-
AudioStateManager
-
Global state manager for audio bubbles to preserve playback state across widget rebuilds
-
BubbleFactory<T extends BaseMessage>
-
Abstract factory for creating message bubble content widgets.
-
CardBubbleStyle
-
CardBubbleStyle is a model class for card widget. It contains the styles for the card widget.
-
CircularIntervalList<T>
-
-
CometChatAudioBubble
-
CometChatAudioBubble creates a widget that gives audio bubble
-
CometChatAudioBubbleStyle
-
CometChatAudioBubbleStyle is a data class that has styling-related properties
to customize the appearance of CometChatAudioBubble
-
CometChatAudioBubbleV2
-
Rewritten CometChatAudioBubble with lazy loading and gesture-controlled waveform
-
CometChatCardBubble
-
CometChatCardBubble creates the card view for InteractiveMessage with type MessageTypeConstants.card by default
-
CometChatColorHelper
-
The CometChatColorHelper class provides methods to blend two colors together and generate a color palette based on the base color and blend color provided.
-
CometChatColorPalette
-
The CometChatColorPalette class provides a color palette for the CometChat UI Kit.
-
CometChatEmailFormatter
-
CometChatEmailFormatter is a class which is used to style the email text
-
CometChatFileBubble
-
CometChatFileBubble creates a widget that gives file bubble
-
CometChatFileBubbleStyle
-
CometChatFileBubbleStyle is a data class that has styling-related properties
to customize the appearance of CometChatFileBubble
-
CometChatImageBubble
-
CometChatImageBubble creates a widget that gives image bubble
-
CometChatImageBubbleStyle
-
CometChatImageBubbleStyle is a data class that has styling-related properties
to customize the appearance of CometChatImageBubble
-
CometChatListBase
-
CometChatListBase is a top level container widget
used internally by components like CometChatUsers, CometChatGroups, CometChatConversations, CometChatGroupMembers
-
CometChatMediaRecorder
-
CometChatMediaRecorder is a class that allows users to record audio messages.
It has a start button to start recording, a stop button to stop recording, a play button to play the recorded message, a pause button to pause the recorded message, a submit button to submit the recorded message and a close button to close the media recorder.
-
CometChatMediaRecorderStyle
-
CometChatMediaRecorderStyle is a model class for customizing the styles of CometChatMediaRecorder widget.
-
CometChatMentionsFormatter
-
CometChatMentionsFormatter is a class which is used to format the mentions
It extends the CometChatTextFormatter
It has properties like composerId, onError, suggestionListEventSink, previousTextEventSink, message, mentionedUsersMap, mentionCount, mentionStartIndex, mentionEndIndex, lastCursorPos
It has methods like handlePreMessageSend, initializeFetchRequest, fetchItems, onMessageEdit, resetMentionsTracker, cursorInMentionTracker, onChange, onScrollToBottom
It has a constructor which takes trackingCharacter, pattern,
disableSuggestions, showLoadingIndicator, onSearch, group, composerId, onError, suggestionListEventSink, previousTextEventSink, theme, message, messageBubbleTextStyle, groupMembersRequestBuilder, usersRequestBuilder, messageInputTextStyle as a parameter
It has a method onMentionTap which is used to handle the mention tap
-
CometChatMentionsStyle
-
CometChatMentionsStyle is a data class that has styling-related properties
to customize the appearance of mentions in the message
-
CometChatMessageInput
-
CometChatMessageInput is a component that provides a skeleton layout for contents of CometChatMessageComposer like TextField, auxiliary options, primary button view and attachment options.
-
CometChatMessageInputStyle
-
CometChatMessageInputStyle is a data class that has styling-related properties
to customize the appearance of CometChatMessageInput
-
CometChatPhoneNumberFormatter
-
CometChatPhoneNumberFormatter is a class which is used to style the phone number text
-
CometChatReactionList
-
CometChatReactionList is a StatefulWidget that displays the list of reactions
for a particular message. It requires reactionRequestBuilder to fetch the
reactions of a particular message. It also requires message to fetch
the reactions of a particular message. It also requires onTap to perform
some action on click of a particular reaction.
-
CometChatReactionListStyle
-
CometChatReactionListStyle is a class which is used to set the style for the reaction list
It takes
loadingStateColor, emptyTextStyle, errorTextStyle, subtitleTextStyle, width, height, background, gradient, border, borderRadius as a parameter
-
CometChatReactions
-
CometChatReactions is a widget which is used to set the reactions
It takes reactionList, theme, alignment, onReactionTap, onReactionLongPress, style as a parameter
-
CometChatReactionsStyle
-
CometChatReactionsStyle is a class which is used to set the style for the reactions
It takes emojiTextStyle, countTextStyle,
width, height, background, gradient, border, borderRadius as a parameter
-
CometChatShimmerEffect
-
-
CometChatSpacing
-
CometChatSpacing is a class that holds the spacing values for the CometChat UI Kit.
-
CometChatTextBubble
-
CometChatTextBubble is a widget that gives text bubble
-
CometChatTextBubbleStyle
-
CometChatTextBubbleStyle is a data class that has styling-related properties
to customize the appearance of CometChatTextBubble
-
CometChatTextFormatter
-
CometChatTextFormatter is an abstract class which is used to format the text
It has properties like trackingCharacter, pattern, onSearch, showLoadingIndicator, messageBubbleTextStyle, messageInputTextStyle
It has methods like init, handlePreMessageSend, onScrollToBottom, buildInputFieldText, mergeAttributedText, getAttributedText, onChange, getLoadingIndicator, getMessageInputTextStyle, getMessageBubbleTextStyle
-
CometChatTextStyleBody
-
CometChatTextStyleBody is a class that gives the styling to the text displayed in the body
-
CometChatTextStyleButton
-
CometChatTextStyleButton is a class that gives the styling to the text displayed in the buttons
-
CometChatTextStyleCaption1
-
CometChatTextStyleCaption1 is a class that gives the styling to the text displayed in the caption
-
CometChatTextStyleCaption2
-
CometChatTextStyleCaption2 is a class that gives the styling to the text displayed in the caption2
-
CometChatTextStyleHeading1
-
CometChatTextStyleHeading1 is a class that gives the styling to the text displayed in the heading1
-
CometChatTextStyleHeading2
-
CometChatTextStyleHeading2 is a class that gives the styling to the text displayed in the heading3
-
CometChatTextStyleHeading3
-
CometChatTextStyleHeading3 is a class that gives the styling to the text displayed in the heading3
-
CometChatTextStyleHeading4
-
CometChatTextStyleHeading4 is a class that gives the styling to the text displayed in the CometChatApp.
-
CometChatTextStyleLink
-
CometChatTextStyleLink is a class that gives the styling to the text displayed in the link
-
CometChatTextStyleTitle
-
CometChatTextStyleTitle is a class that gives the styling to the text displayed in the title
-
CometChatTheme
-
-
CometChatThemeHelper
-
CometChatThemeHelper is a class that gives the styling to the text displayed in the buttons
-
CometChatThemeMode
-
-
CometChatTypography
-
-
CometChatUrlFormatter
-
CometChatUrlFormatter is a class which is used to style the url text
-
CometChatVideoBubble
-
CometChatVideoBubble creates a widget that gives video bubble
-
CometChatVideoBubbleStyle
-
CometChatVideoBubbleStyle is a data class that has styling-related properties
to customize the appearance of CometChatVideoBubble
-
CustomStateView
-
-
DashOffset
-
-
DefaultBubbleFactories
-
Utility class providing default bubble factories for all message types.
-
DeletedBubbleFactory
-
Factory for creating deleted message bubbles.
-
DottedBorder
-
-
FileBubbleFactory
-
Factory for creating file message bubbles.
-
Formatter
-
-
FormatterUtils
-
FormatterUtils is an utility class which is used to style the text in the message bubble and the conversation subtitle
-
ImageBubbleFactory
-
Factory for creating image message bubbles.
-
ListBaseStyle
-
ListBaseStyle is a data class that has styling-related properties
to customize the appearance of CometChatListBase
-
MediaPicker
-
-
MessageListEmpty
-
Empty state - no messages found
-
MessageListError
-
Error state - operation failed
-
MessageListInitial
-
Initial state - before any operation
-
MessageListLoading
-
Loading state - while fetching data
-
MessageListLoadingMore
-
Pagination state - loading more messages
-
MessageListMessageDeleted
-
Message deleted state
-
MessageListMessageSent
-
Message sent state
-
MessageListSearching
-
Search state - searching for messages
-
MessageListSearchResults
-
Search results state
-
MessageListSending
-
Message sending state
-
MessageListState
-
Base state class for all message list states
-
MessageListSuccess
-
Success state - data loaded successfully
-
PickedFile
-
-
SectionSeparator
-
-
TextBubbleFactory
-
Factory for creating text message bubbles.
-
UnreadCountError
-
-
UnreadCountInitial
-
-
UnreadCountLoading
-
-
UnreadCountState
-
State for unread count
-
UnreadCountSuccess
-
-
VideoBubbleFactory
-
Factory for creating video message bubbles.