shared_ui/src/clean_architecture/presentation/views/views library

Classes

AudioBubbleFactory
Factory for creating audio message bubbles.
AudioStateManager
Global state manager for audio bubbles to preserve playback state across widget rebuilds
BubbleFactory<T extends BaseMessage>
Abstract factory for creating message bubble content widgets.
CardBubbleStyle
CardBubbleStyle is a model class for card widget. It contains the styles for the card widget.
CometChatAudioBubble
CometChatAudioBubble creates a widget that gives audio bubble
CometChatAudioBubbleStyle
CometChatAudioBubbleStyle is a data class that has styling-related properties to customize the appearance of CometChatAudioBubble
CometChatAudioBubbleV2
Rewritten CometChatAudioBubble with lazy loading and gesture-controlled waveform
CometChatCardBubble
CometChatCardBubble creates the card view for InteractiveMessage with type MessageTypeConstants.card by default
CometChatFileBubble
CometChatFileBubble creates a widget that gives file bubble
CometChatFileBubbleStyle
CometChatFileBubbleStyle is a data class that has styling-related properties to customize the appearance of CometChatFileBubble
CometChatImageBubble
CometChatImageBubble creates a widget that gives image bubble
CometChatImageBubbleStyle
CometChatImageBubbleStyle is a data class that has styling-related properties to customize the appearance of CometChatImageBubble
CometChatListBase
CometChatListBase is a top level container widget used internally by components like CometChatUsers, CometChatGroups, CometChatConversations, CometChatGroupMembers
CometChatMediaRecorder
CometChatMediaRecorder is a class that allows users to record audio messages. It has a start button to start recording, a stop button to stop recording, a play button to play the recorded message, a pause button to pause the recorded message, a submit button to submit the recorded message and a close button to close the media recorder.
CometChatMediaRecorderStyle
CometChatMediaRecorderStyle is a model class for customizing the styles of CometChatMediaRecorder widget.
CometChatMessageInput
CometChatMessageInput is a component that provides a skeleton layout for contents of CometChatMessageComposer like TextField, auxiliary options, primary button view and attachment options.
CometChatMessageInputStyle
CometChatMessageInputStyle is a data class that has styling-related properties to customize the appearance of CometChatMessageInput
CometChatReactionList
CometChatReactionList is a StatefulWidget that displays the list of reactions for a particular message. It requires reactionRequestBuilder to fetch the reactions of a particular message. It also requires message to fetch the reactions of a particular message. It also requires onTap to perform some action on click of a particular reaction.
CometChatReactionListStyle
CometChatReactionListStyle is a class which is used to set the style for the reaction list It takes loadingStateColor, emptyTextStyle, errorTextStyle, subtitleTextStyle, width, height, background, gradient, border, borderRadius as a parameter
CometChatReactions
CometChatReactions is a widget which is used to set the reactions It takes reactionList, theme, alignment, onReactionTap, onReactionLongPress, style as a parameter
CometChatReactionsStyle
CometChatReactionsStyle is a class which is used to set the style for the reactions It takes emojiTextStyle, countTextStyle, width, height, background, gradient, border, borderRadius as a parameter
CometChatTextBubble
CometChatTextBubble is a widget that gives text bubble
CometChatTextBubbleStyle
CometChatTextBubbleStyle is a data class that has styling-related properties to customize the appearance of CometChatTextBubble
CometChatVideoBubble
CometChatVideoBubble creates a widget that gives video bubble
CometChatVideoBubbleStyle
CometChatVideoBubbleStyle is a data class that has styling-related properties to customize the appearance of CometChatVideoBubble
DefaultBubbleFactories
Utility class providing default bubble factories for all message types.
DeletedBubbleFactory
Factory for creating deleted message bubbles.
FileBubbleFactory
Factory for creating file message bubbles.
ImageBubbleFactory
Factory for creating image message bubbles.
ListBaseStyle
ListBaseStyle is a data class that has styling-related properties to customize the appearance of CometChatListBase
TextBubbleFactory
Factory for creating text message bubbles.
VideoBubbleFactory
Factory for creating video message bubbles.

Typedefs

BubbleViewProvider = Widget? Function(BuildContext context, BaseMessage message, BubbleAlignment alignment)
Callback for providing custom views for message bubble slots. Returns Widget or null to use default/hide.