shared_ui/src/constants/asset_constants library
Classes
- AssetConstants
- AssetConstants is a utility class that stores String constants of asset image paths
- SvgAssetConstants
- SvgAssetConstants is a utility class that stores String constants of asset image paths
Extensions
- CometChatAssetConstants on AssetConstants
- CometChatAssetConstants is an extension that provides asset image paths according to the brightness mode of the device