shared_ui/src/constants/ui_kit_constants library
Classes
- ActionElementFields
- ActionMessageTypeConstants
- ActionTypeConstants
- APIRequestTypeConstants
- AudioBubbleConstants
- CallStatusConstants
- CallStatusConstants is a utility class that stores String constants of various stages of Call
- CallTypeConstants
- CardMessageKeys
- CometChatStartConversationType
-
CometChatStartConversationType is a utility class that stores String constants of the types of
CometChatContacts - ConversationOptionConstants
- ConversationOptionConstants is a utility class that stores String constants of options available for Conversation items
- DetailsTemplateConstants
- DetailsTemplateConstants is a utility class that stores String constants of the types of CometChatDetailsTemplate
- ErrorConstants
- ExtensionType
- FileConstants
- GroupMemberOptionConstants
- GroupMemberOptionConstants is a utility class that stores String constants of the actions permitted to a GroupMember to execute on a particular Group
- GroupMemberScope
- GroupMemberScope is a utility class that stores String constants of scope of GroupMember with respect to a particular Group
- GroupOptionConstants
-
GroupOptionConstants is a utility class that stores String constants of the options available in
CometChatDetailsif it is being rendered for a Group - GroupTypeConstants
- GroupTypeConstants is a utility class that stores String constants of the types of Group
- IDMapConstants
- InteractionGoalTypeConstants
- InteractiveMessageConstants
- LiveReactionConstants
- LiveReactionConstants is a utility class that stores constant values related to functioning of TransientMessage
- MessageCategoryConstants
- MessageCategoryConstants is a utility class that stores String constants of categories of messages
- MessageOptionConstants
- MessageOptionConstants is a utility class that stores String constants of the actions permitted to execute on a particular BaseMessage
- MessageTypeConstants
- MessageTypeConstants is a utility class that stores String constants of types of messages
- MetadataConstants
-
MetadataConstants is a utility class that stores String constants to use in the
metadataproperty of a BaseMessage - ModelFieldConstants
- ReactionConstants
- ReceiptTypeConstants
- ReceiptTypeConstants is a utility class that stores String constants of the various stages of message delivery
- ReceiverTypeConstants
- ReceiverTypeConstants is a utility class that stores String constants of the types of AppEntity that can receive a BaseMessage
- SchedulerConstants
- SetSourceConstant
- UIConstants
- UIConstants contains properties essential and limited to setting up the ui kit
- UIElementTypeConstants
- UITabNameConstants
-
UITabNameConstants is a utility class that stores String constants of the names of the tabs available for
CometChatUI - UpdateSettingsConstant
- UserOptionConstants
-
UserOptionConstants is a utility class that stores String constants of the options available in
CometChatDetailsif it is being rendered for a User - UserStatusConstants
- UserStatusConstants is a utility class that stores String constants of the online/offline status of an User
Typedefs
-
ComposerActionsBuilder
= List<
CometChatMessageComposerAction> Function(BuildContext context, User? user, Group? group, Map<String, dynamic> ? id) -
ComposerWidgetBuilder
= Widget Function(BuildContext context, User? user, Group? group, Map<
String, dynamic> ? id) - OnEmpty = void Function()
- OnEmpty defines the structure of empty handler used by the components in the ui kit
- OnError = dynamic Function(Exception e)
- OnError defines the structure of error handler used by the components in the ui kit
-
OnLoad<
T> = dynamic Function(List< T> list) - OnLoad defines the structure of loading handler used by the components in the ui kit
- UserGroupBuilder = dynamic Function(BuildContext context, User? user, Group? group)