AdditionalConfigurations class
AdditionalConfigurations is a class that can be used to add additional configurations to the UI Kit
AdditionalConfigurations(
textFormatters: [
CometChatPhoneNumberFormatter(
pattern: RegExp(RegexConstants.phoneNumberRegexPattern),
onSearch: (phoneNumber) async {
await launchUrl(Uri.parse(('tel:$phoneNumber')));
},
messageBubbleTextStyle: (theme, alignment,{forConversation}) {
return TextStyle(
color: Colors.pink,
);
},
),
CometChatEmailFormatter(
pattern: RegExp(RegexConstants.emailRegexPattern),
onSearch: (email) async {
await launchUrl(Uri.parse(('mailto:$email')));
},
messageBubbleTextStyle: (theme, alignment,{forConversation}) {
return TextStyle(
color: Colors.red,
);
},
),
],
);
Constructors
-
AdditionalConfigurations({List<
CometChatTextFormatter> ? textFormatters, CometChatTextBubbleStyle? textBubbleStyle, CometChatImageBubbleStyle? imageBubbleStyle, CometChatVideoBubbleStyle? videoBubbleStyle, CometChatAudioBubbleStyle? audioBubbleStyle, CometChatFileBubbleStyle? fileBubbleStyle, CometChatAttachmentOptionSheetStyle? attachmentOptionSheetStyle, CometChatMessageOptionSheetStyle? messageOptionSheetStyle, CometChatCollaborativeBubbleStyle? collaborativeDocumentBubbleStyle, CometChatCollaborativeBubbleStyle? collaborativeWhiteboardBubbleStyle, CometChatPollsBubbleStyle? pollsBubbleStyle, CometChatActionBubbleStyle? actionBubbleStyle, CometChatDeletedBubbleStyle? deletedBubbleStyle, CometChatMessageTranslationBubbleStyle? messageTranslationBubbleStyle, CometChatLinkPreviewBubbleStyle? linkPreviewBubbleStyle, CometChatStickerBubbleStyle? stickerBubbleStyle, CometChatCallBubbleStyle? voiceCallBubbleStyle, CometChatCallBubbleStyle? videoCallBubbleStyle, CometChatCallButtonsStyle? callButtonsStyle, bool? hideVideoCallButton, bool? hideVoiceCallButton, bool? hideImageAttachmentOption, bool? hideVideoAttachmentOption, bool? hideAudioAttachmentOption, bool? hideFileAttachmentOption, bool? hidePollsOption, bool? hideCollaborativeDocumentOption, bool? hideCollaborativeWhiteboardOption, bool? hideStickersButton, bool? hideTakPhotoOption, bool? hideCopyMessageOption, bool? hideDeleteMessageOption, bool? hideEditMessageOption, bool? hideReactionOption, bool? hideMessagePrivatelyOption, bool? hideMessageInfoOption, bool? hideTranslateMessageOption, bool? hideReplyInThreadOption, bool? hideReplyOption, bool? showMarkAsUnreadOption, bool? hideFlagOption})
Properties
- actionBubbleStyle → CometChatActionBubbleStyle?
-
actionBubbleStyle is a CometChatActionBubbleStyle that can be used to style action bubble
final
- attachmentOptionSheetStyle → CometChatAttachmentOptionSheetStyle?
-
attachmentOptionSheetStyle is a CometChatAttachmentOptionSheetStyle that can be used to style attachment option sheet
final
- audioBubbleStyle → CometChatAudioBubbleStyle?
-
audioBubbleStyle is a CometChatAudioBubbleStyle that can be used to style audio bubble
final
- callButtonsStyle → CometChatCallButtonsStyle?
-
callButtonsStyle is a CometChatCallButtonsStyle that can be used to style call buttons
final
- collaborativeDocumentBubbleStyle → CometChatCollaborativeBubbleStyle?
-
collaborativeDocumentBubbleStyle provides style to the collaborative document bubble of the sent message
final
- collaborativeWhiteboardBubbleStyle → CometChatCollaborativeBubbleStyle?
-
collaborativeWhiteboardBubbleStyle provides style to the collaborative whiteboard bubble of the sent message
final
- deletedBubbleStyle → CometChatDeletedBubbleStyle?
-
deletedBubbleStyle is a CometChatDeletedBubbleStyle that can be used to style deleted bubble
final
- fileBubbleStyle → CometChatFileBubbleStyle?
-
fileBubbleStyle is a CometChatFileBubbleStyle that can be used to style file bubble
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hideAudioAttachmentOption → bool?
-
hideAudioAttachmentOption is a bool that can be used to hide/display audio attachment option
final
- hideCollaborativeDocumentOption → bool?
-
hideCollaborativeDocumentOption is a bool that can be used to hide/display collaborative document option
final
- hideCollaborativeWhiteboardOption → bool?
-
hideCollaborativeWhiteboardOption is a bool that can be used to hide/display collaborative whiteboard option
final
- hideCopyMessageOption → bool?
-
hideCopyMessageOption This prop defines whether a user can copy message or not.
final
- hideDeleteMessageOption → bool?
-
hideDeleteMessageOption This prop defines whether Delete Message option should be visible or not.
final
- hideEditMessageOption → bool?
-
hideEditMessageOption This prop defines whether Edit Message option should be visible or not.
final
- hideFileAttachmentOption → bool?
-
hideFileAttachmentOption is a bool that can be used to hide/display file attachment option
final
- hideFlagOption → bool?
-
hideFlagOption This prop defines whether the Flag/Report option should be visible or not.
final
- hideImageAttachmentOption → bool?
-
hideImageAttachmentOption is a bool that can be used to hide/display image attachment option
final
- hideMessageInfoOption → bool?
-
hideMessageInfoOption This prop defines whether a user can fetch information about the message whether it's received or not.
final
- hideMessagePrivatelyOption → bool?
-
hideMessagePrivatelyOption This prop defines whether a user can privately message other member of the group or not.
final
- hidePollsOption → bool?
-
hidePollsOption is a bool that can be used to hide/display poll option
final
- hideReactionOption → bool?
-
hideReactionOption This prop defines whether Reaction option should be visible or not.
final
- hideReplyInThreadOption → bool?
-
hideReplyInThreadOption This prop defines whether Reply In Thread option should be visible or not.
final
- hideReplyOption → bool?
-
hideReplyOption This prop defines whether the inline Reply option should be visible or not.
final
-
hideShareMessageOption This prop defines whether share option should be visible or not.
final
- hideStickersButton → bool?
-
hideStickersButton is a bool that can be used to hide/display sticker button
final
- hideTakPhotoOption → bool?
-
hideTakPhotoOption is a bool that can be used to hide/display take photo option
final
- hideTranslateMessageOption → bool?
-
hideTranslateMessageOption This prop defines whether Reply In Thread option should be visible or not.
final
- hideVideoAttachmentOption → bool?
-
hideVideoAttachmentOption is a bool that can be used to hide/display video attachment option
final
- hideVideoCallButton → bool?
-
hideVideoCallButton is a bool that can be used to hide/display video call button
final
- hideVoiceCallButton → bool?
-
hideVoiceCallButton is a bool that can be used to hide/display voice call button
final
- imageBubbleStyle → CometChatImageBubbleStyle?
-
imageBubbleStyle is a CometChatImageBubbleStyle that can be used to style image bubble
final
- linkPreviewBubbleStyle → CometChatLinkPreviewBubbleStyle?
-
linkPreviewBubbleStyle is a CometChatLinkPreviewBubbleStyle that can be used to style link preview bubble
final
- messageOptionSheetStyle → CometChatMessageOptionSheetStyle?
-
messageOptionSheetStyle is a CometChatMessageOptionSheetStyle that can be used to style message option sheet
final
- messageTranslationBubbleStyle → CometChatMessageTranslationBubbleStyle?
-
messageTranslationBubbleStyle is a CometChatMessageTranslationBubbleStyle that can be used to style message translation bubble
final
- pollsBubbleStyle → CometChatPollsBubbleStyle?
-
pollsBubbleStyle is a CometChatPollsBubbleStyle that can be used to style polls bubble
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showMarkAsUnreadOption → bool?
-
showMarkAsUnreadOption This prop defines whether Mark as Unread option should be visible or not.
final
- stickerBubbleStyle → CometChatStickerBubbleStyle?
-
stickerBubbleStyle is a CometChatStickerBubbleStyle that can be used to style sticker bubble
final
- textBubbleStyle → CometChatTextBubbleStyle?
-
textBubbleStyle is a CometChatTextBubbleStyle that can be used to style text bubble
final
-
textFormatters
→ List<
CometChatTextFormatter> ? -
textFormatters is a list of CometChatTextFormatter that can be used to format text
final
- videoBubbleStyle → CometChatVideoBubbleStyle?
-
videoBubbleStyle is a CometChatVideoBubbleStyle that can be used to style video bubble
final
- videoCallBubbleStyle → CometChatCallBubbleStyle?
-
videoCallBubbleStyle is a CometChatCallBubbleStyle that can be used to style video call bubble
final
- voiceCallBubbleStyle → CometChatCallBubbleStyle?
-
voiceCallBubbleStyle is a CometChatCallBubbleStyle that can be used to style voice call bubble
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited