audioBubbleStyle property
audioBubbleStyle is a CometChatAudioBubbleStyle that can be used to style audio bubble
Implementation
final CometChatAudioBubbleStyle? audioBubbleStyle;
audioBubbleStyle is a CometChatAudioBubbleStyle that can be used to style audio bubble
final CometChatAudioBubbleStyle? audioBubbleStyle;