hideMessagePrivatelyOption property
hideMessagePrivatelyOption This prop defines whether a user can privately message other member of the group or not.
Implementation
final bool? hideMessagePrivatelyOption;
hideMessagePrivatelyOption This prop defines whether a user can privately message other member of the group or not.
final bool? hideMessagePrivatelyOption;