CustomAction class
Represents a custom action in a chat application.
This action is used for custom actions that are not specifically related to API requests or URL navigation. It inherits the common 'actionType' property from the ActionEntity class.
- Inheritance
-
- Object
- ActionEntity
- CustomAction
Constructors
- CustomAction({String? actionType})
- CustomAction.fromMap(dynamic map)
-
factory
Properties
- actionType ↔ String
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited