CometChatThemeHelper class
CometChatThemeHelper is a class that gives the styling to the text displayed in the buttons
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getBrightness(
BuildContext context) → Brightness -
getColorPalette(
BuildContext context) → CometChatColorPalette - Get the color palette from the current theme or return the default color palette
-
getSpacing(
BuildContext context) → CometChatSpacing - Get the default spacing values used in the UI components
-
getTheme<
T extends ThemeExtension< (T> >{required BuildContext context, required T defaultTheme(BuildContext context)}) → T - Get the theme extension from the current theme or return the default theme
-
getTypography(
BuildContext context) → CometChatTypography - Get the default text styles used in the UI components