ConversationUtils class
ConversationUtils is an Utility class that helps to the last message for any conversation and also provides the default action to execute on a conversation
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getDefaultOptions(
Conversation conversation, dynamic controller, BuildContext context, CometChatColorPalette colorPalette) → List< CometChatOption> ? - Get default options for a conversation
-
getDefaultOptionsWithCallback(
{required Conversation conversation, required BuildContext context, required CometChatColorPalette colorPalette, required dynamic onDelete(Conversation)?}) → List< CometChatOption> ? - Get default options for a conversation with custom delete callback
-
getLastActionMessage(
Conversation conversation, BuildContext context) → String -
getLastCallMessage(
Conversation conversation, BuildContext context) → String -
getLastCallWidget(
Conversation conversation, BuildContext context, Color? iconColor) → Widget -
getLastConversationIcon(
Conversation conversation, BuildContext context, Color? iconColor) → Widget -
getLastConversationMessage(
Conversation conversation, BuildContext context) → String -
getLastCustomMessage(
Conversation conversation, BuildContext context) → String -
getLastCustomWidget(
Conversation conversation, BuildContext context, Color? iconColor) → Widget -
getLastInteractiveMessage(
Conversation conversation, BuildContext context) → String -
getLastMessage(
Conversation conversation, BuildContext context) → String -
getLastMessageWidget(
Conversation conversation, BuildContext context, Color? iconColor) → Widget -
stripMarkdownSyntax(
String text) → String - Strips markdown syntax from text so conversation subtitles show plain text. Handles: bold, italic, strikethrough, inline code, code blocks, blockquotes, bullet lists, ordered lists, and headings.