CometChatMessageBubbleStyleData class
CometChatMessageBubbleStyleData is a model class which contains the style properties for the message bubble.
Constructors
- CometChatMessageBubbleStyleData({Color? backgroundColor, BoxBorder? border, BorderRadiusGeometry? borderRadius, CometChatDateStyle? messageBubbleDateStyle, CometChatAvatarStyle? messageBubbleAvatarStyle, DecorationImage? messageBubbleBackgroundImage, Color? threadedMessageIndicatorIconColor, TextStyle? threadedMessageIndicatorTextStyle, TextStyle? senderNameTextStyle, CometChatMessageReceiptStyle? messageReceiptStyle, Color? moderationBackgroundColor, TextStyle? moderationTextStyle, Color? moderationIconTint, Color? exceptionBackgroundColor, TextStyle? exceptionTextStyle, Color? exceptionIconTint})
Properties
- backgroundColor ↔ Color?
-
backgroundColor provides background color to the message bubble of a received message
getter/setter pair
- border ↔ BoxBorder?
-
border provides border to the message bubble of a received message
getter/setter pair
- borderRadius ↔ BorderRadiusGeometry?
-
borderRadius provides border radius to the message bubble of a received message
getter/setter pair
- exceptionBackgroundColor → Color?
-
exceptionBackgroundColor provides background color to the exception view
final
- exceptionIconTint → Color?
-
exceptionIconTint provides icon color for the exception view warning icon
final
- exceptionTextStyle → TextStyle?
-
exceptionTextStyle provides text style to the exception view warning text
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageBubbleAvatarStyle ↔ CometChatAvatarStyle?
-
messageBubbleAvatarStyle provides style to the avatar of the senderCometChatAvatarStyle? messageBubbleAvatarStyle;
getter/setter pair
- messageBubbleBackgroundImage ↔ DecorationImage?
-
messageBubbleBackgroundImage provides background image to the message bubble of a received message
getter/setter pair
- messageBubbleDateStyle ↔ CometChatDateStyle?
-
messageBubbleDateStyle provides style to the date of the message bubble
getter/setter pair
- messageReceiptStyle ↔ CometChatMessageReceiptStyle?
-
messageReceiptStyle provides style to the message receipt
getter/setter pair
- moderationBackgroundColor → Color?
-
moderationBackgroundColor provides background color to the moderated view
final
- moderationIconTint → Color?
-
moderationIconTint provides icon color for the moderated view warning icon
final
- moderationTextStyle → TextStyle?
-
moderationTextStyle provides text style to the moderated view warning text
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderNameTextStyle ↔ TextStyle?
-
senderNameTextStyle provides style to the sender name of the received message
getter/setter pair
- threadedMessageIndicatorIconColor ↔ Color?
-
threadedMessageIndicatorIconColor provides color to the threaded message icon
getter/setter pair
- threadedMessageIndicatorTextStyle ↔ TextStyle?
-
threadedMessageIndicatorTextStyle provides text style to the threaded message indicator
getter/setter pair
Methods
-
copyWith(
{DecorationImage? messageBubbleBackgroundImage, Color? backgroundColor, BoxBorder? border, BorderRadiusGeometry? borderRadius, TextStyle? threadedMessageIndicatorTextStyle, Color? threadedMessageIndicatorIconColor, CometChatAvatarStyle? messageBubbleAvatarStyle, CometChatDateStyle? messageBubbleDateStyle, TextStyle? senderNameTextStyle, CometChatMessageReceiptStyle? messageReceiptStyle, Color? moderationBackgroundColor, TextStyle? moderationTextStyle, Color? moderationIconTint, Color? exceptionBackgroundColor, TextStyle? exceptionTextStyle, Color? exceptionIconTint}) → CometChatMessageBubbleStyleData -
merge(
CometChatMessageBubbleStyleData? other) → CometChatMessageBubbleStyleData -
mergeIfNull(
CometChatMessageBubbleStyleData? other) → CometChatMessageBubbleStyleData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited