MessageUtils class
A utility class for message related operations. This class contains methods required for message related operations. It is used to get the message bubble, message time, and message receipt icon.
MessageUtils.getMessageBubble(
message: message,
template: messageTemplate,
bubbleAlignment: BubbleAlignment.left,
colorPalette: colorPalette,
typography: typography,
spacing: spacing,
context: context,
);
- Available extensions
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getMessageBubble(
{required BaseMessage message, CometChatMessageTemplate? template, required BubbleAlignment bubbleAlignment, required CometChatColorPalette colorPalette, required CometChatTypography typography, required CometChatSpacing spacing, required BuildContext context, List< CometChatTextFormatter> ? textFormatters, CometChatOutgoingMessageBubbleStyle? outgoingMessageBubbleStyle, CometChatIncomingMessageBubbleStyle? incomingMessageBubbleStyle, Key? key, bool? receiptsVisibility}) → Widget