shared_ui/src/utils/timezone_utils/location library
TimeZone Location Info.
Most of this code were taken from the go standard library http://golang.org/src/pkg/time/zoneinfo.go and ported to Dart.
Classes
- Location
- A Location maps time instants to the zone in use at that time. Typically, the Location represents the collection of time offsets in use in a geographical area, such as CEST and CET for central Europe.
- TimeZone
- A TimeZone represents a single time zone such as CEST or CET.
- TzInstant
- A TzInstant represents a timezone and an instant in time.